@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,12 +24,19 @@ the mpd module:
 	MusicalPitch
 	MusicDisplayer
 """
+if __name__ == '__main__':
+    import sys
+    sys.path.append(".")
+    sys.path.append("src")
+    import i18n
+    i18n.setup_srcdir()
 
 LOWEST_NOTENAME="c,,,,"
 HIGHEST_NOTENAME="g''''''"
 from const import FIRST, LAST, ALL
 
-import parser, soundcard
+import parser
+import soundcard
 import string, types
 from musicalpitch import MusicalPitch
 from interval import Interval
@@ -104,3 +111,13 @@ def select_clef(s):
     else:
         return "bass"
 
+def _test():
+    import doctest, musicalpitch, duration, interval
+    for mod in (duration, musicalpitch, interval, ):
+        doctest.testmod(mod)
+        # FIXME calling setup_srcdir should not be necessary here.
+        # But doctest.testmod does something strange with _.
+        i18n.setup_srcdir()
+
+if __name__ == '__main__':
+    _test()
