@@ -1,7 +1,7 @@
 #!/usr/bin/python
 
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,9 +22,9 @@
 
 import sys
 
-if sys.version_info < (2, 2):
+if sys.version_info < (2, 3):
     print "********************************************************************"
-    print "Solfege need Python 2.2 or newer. The configure script told you so!"
+    print "Solfege need Python 2.3 or newer. The configure script told you so!"
     print "********************************************************************"
     sys.exit(-1)
 
@@ -33,10 +33,8 @@ import src.configureoutput
 
 src.configureoutput.prefix = "."
 
-import src.rcfile
-src.rcfile.copy_rc_file()
 import src.cfg
-
+__builtins__.app_running = True
 src.cfg.initialise(None, "default.config", "~/.solfegerc")
 
 if '--txtui' in sys.argv:
