@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,6 +22,9 @@ import soundcard, mpd
 import dataparser
 
 import const, utils, string
+import os
+import sys
+import signal
 import types
 import cfg
 
@@ -56,7 +59,7 @@ class Teacher(cfg.ConfigUtils):
                 def remove_timeout(self=self):
                     self.m_timeout_handle = None
                     self.g_view.new_question()
-                self.m_timeout_handle = gtk.timeout_add(self.get_float('seconds_before_new_question')*1000,  remove_timeout)
+                self.m_timeout_handle = gtk.timeout_add((self.get_int('seconds_before_new_question')*1000),  remove_timeout)
     def end_practise(self):
         if self.m_timeout_handle:
             gtk.timeout_remove(self.m_timeout_handle)
@@ -155,22 +158,31 @@ class MelodicIntervalTeacher(Teacher):
         soundcard.synth.play_track(m)
 
 class LessonbasedTeacher(Teacher):
-    def __init__(self, exname, app, content_type):
+    def __init__(self, exname, app):
         Teacher.__init__(self, exname, app)
         self.m_P = None
-        self.m_content_type = content_type
         self.m_question = None
         self.__make_sure_existing_lessonfile_is_selected()
-    def set_lessoncollection(self, collection):
-        self.set_string('lessoncollection', collection)
+    def set_lessonfile(self, lessoncollection, lessonfile):
+        """
+        Set the config variables 'lessonfile' and 'lessoncollection'
+        Parse the lesson file and save the statistics.
+        """
+        if lessonfile is not None \
+                and lessonfile == self.get_string('lessonfile'):
+            new_file = 0
+        else:
+            new_file = 1
+        if lessoncollection:
+            self.set_string('lessoncollection', lessoncollection)
+        if lessonfile:
+            self.set_string('lessonfile', lessonfile)
         self.__make_sure_existing_lessonfile_is_selected()
         self.parse_lessonfile()
-        if self.m_statistics:
-            self.m_statistics.lessonfile_changed(
-             self.get_string('lessoncollection'), self.get_string('lessonfile'))
-    def set_lessonfile(self, file):
-        self.set_string('lessonfile', file)
-        self.parse_lessonfile()
+        if new_file and self.m_P.header.questions_selectable:
+            self.block_watch('ask_for_names')
+            self.set_list('ask_for_names', range(0, len(self.m_P.get_unique_cnames())))
+            self.unblock_watch('ask_for_names')
         if self.m_statistics:
             self.m_statistics.lessonfile_changed(
              self.get_string('lessoncollection'), self.get_string('lessonfile'))
@@ -180,7 +192,7 @@ class LessonbasedTeacher(Teacher):
                  not in self.m_app.lessonfile_manager.get_collections():
             self.set_string('lessoncollection', 'solfege')
         F = self.m_app.lessonfile_manager.get_filenames(
-                 self.get_string('lessoncollection'), self.m_content_type)
+                 self.get_string('lessoncollection'), self.m_exname)
         if F:
             if self.get_string('lessonfile') not in F:
                 self.set_string('lessonfile', F[0])
@@ -196,19 +208,16 @@ class LessonbasedTeacher(Teacher):
              self.get_string('lessoncollection'),
              self.get_string('lessonfile'))
         try:
-            self.m_P = self.lessonfileclass(fn)
+            self.m_P = self.lessonfileclass(fn, self)
         except IOError:
             self.m_app.m_ui.display_error_message(
 """There was an IOError while trying to parse a lesson file. The cause was probably you deleting or renaming a lesson file. Please don't do this while Solfege is running. The program is still a little fragile. 
 
 You really should reastart the program now.""")
-    def play_question(self):
-        if self.q_status == const.QSTATUS_NO:
-            return
-        mpd.play_music(self.m_P.get_music(),
-                           self.m_P.get_tempo(),
-                           self.get_int('config/preferred_instrument'),
-                           self.get_int('config/preferred_instrument_velocity'))
+        if self.m_P.header.musicformat == "cmdline":
+            run = self.m_app.m_ui.dialog_yesno("The lessonfile contain dangerous code because musicformat=\"cmdline\". Run anyway?")
+            if not run:
+                self.m_P = None
     def configure_exercise(self, lessoncollection, lessonfile, dict):
         if lessoncollection or lessonfile:
             if lessoncollection:
@@ -244,14 +253,14 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
 
         self.action_area = gtk.HBox()
         self.action_area.show()
-        vbox.pack_end(self.action_area, gtk.FALSE)
+        vbox.pack_end(self.action_area, False)
 
         self.config_box = gtk.VBox()
         self.config_box.set_border_width(gnome.ui.PAD)
         self.config_box.show()
         if no_notebook:
             self.pack_start(vbox)
-            self.pack_start(self.config_box, gtk.FALSE)
+            self.pack_start(self.config_box, False)
             self.g_notebook = None
         else:
             self.g_notebook = gtk.Notebook()
@@ -294,7 +303,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
     def get_pretty_name(self):
         return string.replace(const.exercisedata[self.m_exname][0], '_', '')
     def _add_auto_new_question_gui(self, box):
-        hbox = gu.bHBox(box, gtk.FALSE)
+        hbox = gu.bHBox(box, False)
         hbox.set_spacing(gnome.ui.PAD_SMALL)
         adj = gtk.Adjustment(0, 0, 10, 0.1, 1, 1)
         spin = gu.nSpinButton(self.m_exname, 'seconds_before_new_question',
@@ -307,11 +316,11 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
             label.set_sensitive(button.get_active())
         b = gu.nCheckButton(self.m_exname, 'new_question_automatically',
                             _("_New question automatically."), callback=f)
-        hbox.pack_start(b, gtk.FALSE)
+        hbox.pack_start(b, False)
         label.set_sensitive(b.get_active())
-        hbox.pack_start(label, gtk.FALSE)
+        hbox.pack_start(label, False)
         spin.set_sensitive(b.get_active())
-        hbox.pack_start(spin, gtk.FALSE)
+        hbox.pack_start(spin, False)
 
 class IntervalGui(Gui):
     """
@@ -324,13 +333,13 @@ class IntervalGui(Gui):
 
         self.g_flashbar = gu.FlashBar()
         self.g_flashbar.show()
-        self.practise_box.pack_start(self.g_flashbar, gtk.FALSE)
+        self.practise_box.pack_start(self.g_flashbar, False)
         self.practise_box.set_spacing(gnome.ui.PAD)
 
         self.g_new_interval = gu.bButton(self.action_area, _("_New interval"),
                                           self.new_question)
         self.g_repeat = gu.bButton(self.action_area, _("_Repeat"), self.repeat_question)
-        self.g_repeat.set_sensitive(gtk.FALSE)
+        self.g_repeat.set_sensitive(False)
         self.setup_key_bindings()
     def select_inputwidget(self):
         """
