@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,16 +15,74 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+try:
+    app_running == True
+except:
+    import sys
+    sys.path.append("src")
+    sys.path.append(".")
+    import i18n
+    i18n.setup_srcdir()
+
+
 import configureoutput
 import errno, sys
 import shutil
-
+import signal
 import soundcard, mpd
 import lessonfile
 import statistics
 import os
 import cfg, utils
 
+class RunExternalFailed(Exception):
+    def __init__(self, v):
+        self.v = v
+    def __str__(self):
+        return "\nRunning external program failed.\nPlease check your setup.\nThe command that failed was: '%s'" % (" ".join(self.v[1:]))
+
+__child_pid = None
+def run_external_program(cmdstring, wdir, argument):
+    global __child_pid
+    if cmdstring.find("%s") == -1:
+        cmdline = "%s %s" % (cmdstring, argument)
+    else:
+        cmdline = cmdstring % argument
+    wdir = os.path.normpath(wdir)
+    dir_up = wdir.count("/") * "../" + ".."
+    v = cmdline.split()
+    v = v[:1] + v
+    os.chdir(wdir)
+    if not os.path.exists(v[0]):
+        raise RunExternalFailed(v)
+        #self.m_ui.display_error_message("'%s' does not exist." %v[0],
+        #        _("Running external program failed"))
+        os.chdir(dir_up)
+        return
+    os.chdir(dir_up)
+    try:
+        if __child_pid is not None:
+            os.kill(__child_pid, signal.SIGKILL)
+            os.wait()
+        __child_pid = None
+    except OSError:
+        print "kill failed, OSError"
+    except AttributeError:
+        __child_pid = None
+    pid = os.fork()
+    if pid == 0:
+        os.chdir(wdir)
+        try:
+            apply(os.execlp, v)
+        except OSError, x:
+            print >> sys.stderr, "OS Error:", x
+            os._exit(-1)
+            os.chdir("..")
+        os.chdir("..")
+    else:
+        __child_pid = pid
+
+
 class SolfegeApp(cfg.ConfigUtils):
     def __init__(self, argv, ui):
         cfg.ConfigUtils.__init__(self, 'solfege-app')
@@ -34,11 +92,21 @@ class SolfegeApp(cfg.ConfigUtils):
         self.m_teachers = {}
         self.m_running_exercise = None
         self.lessonfile_manager = lessonfile.LessonFileManager()
-        self.m_sound_init_exception = None
         self.setup_sound()
     def check_rcfile(self):
-        if cfg.get_int("app/rcfileversion") > 1:
+        """See default.config for rcfileversion values, meanings and
+        a description of how to add config variables.
+        """
+        if cfg.get_int("app/rcfileversion") > 3:
             cfg.drop_user_config()
+        if cfg.get_int("app/rcfileversion") == 1:
+            if not "example-files" in cfg.get_string('config/lessoncollections'):
+                cfg.set_string('config/lessoncollections', 
+                    "%s example-files" % cfg.get_string('config/lessoncollections'))
+            cfg.set_int("app/rcfileversion", 2)
+        if cfg.get_int("app/rcfileversion") == 2:
+            cfg.del_key("sound/commandline")
+            cfg.set_int("app/rcfileversion", 3)
     def setup_sound(self):
         if sys.platform == 'win32' and \
                     cfg.get_string("sound/type") == "sequencer-device":
@@ -51,13 +119,13 @@ class SolfegeApp(cfg.ConfigUtils):
             try:
                 soundcard.initialise_winsynth(cfg.get_int("sound/synth_number"),
                       verbose_init='--verbose-sound-init' in self.m_argv)
-            except:
+            except:#FIXME should use except: ExceptionName
                 cfg.set_int("sound/synth_number", 0)
                 soundcard.initialise_winsynth(cfg.get_int("sound/synth_number"),
                       verbose_init='--verbose-sound-init' in self.m_argv)
         elif cfg.get_string("sound/type") == "external-midiplayer":
             soundcard.initialise_external_midiplayer(
-                    cfg.get_string("sound/commandline"),
+                    cfg.get_string("sound/midi_player"),
                     verbose_init='--verbose-sound-init' in self.m_argv)
         elif cfg.get_string("sound/type") == '':
             self.m_ui.display_error_message(
@@ -76,8 +144,14 @@ the preferences window.
                              cfg.get_string("sound/card_info"),
                              verbose_init='--verbose-sound-init' in self.m_argv)
             except (soundcard.SoundInitException, OSError), e:
-                self.m_sound_init_exception = e
-                soundcard.initialise_using_fake_synth(True)
+                if e == None:
+                    self.m_ui.display_error_message(
+"""You should configure sound
+from the 'Sound' page of
+the preferences window.
+""")
+                else:
+                    self.display_sound_init_error_message(e)
     def display_sound_init_error_message(self, e):
         if isinstance(e, soundcard.SoundInitException):
             self.m_ui.display_error_message(
@@ -96,12 +170,10 @@ should try to quit that other program and restart Solfege."""
         else:
             self.m_ui.display_error_message(
 """The sound init failed: %s
-It seems like your kernel don't have the correct
-sound modules installed, or that they are wrongly
-configured. You can check the 'Sound' page in the
-preferences window, but I don't think anything there
-can help you. (This program need better sound init
-code to handle situations like this.)"""
+You should configure sound
+from the 'Sound' page of
+the preferences window.
+"""
  % errno.errorcode[e.errno])
     def play_happy_sound(self):
         mpd.play_music(r"\staff\relative c'{c16 e g a}", 180, 8,
@@ -123,7 +195,11 @@ code to handle situations like this.)"""
         protocol, action, fn, anchor, lessoncollection, lessonfile, config = \
            utils.parse_url(href)
         if protocol == None:
-            self.m_ui.display_docfile(fn, anchor)
+            if fn.endswith(".midi"):
+                run_external_program(self.get_string("sound/midi_player"),
+                        self.m_ui.box_dict['docviewer'].m_htmlwidget.m_document_wd, fn)
+            else:
+                self.m_ui.display_docfile(fn, anchor)
         elif protocol == 'solfege':
             if action == 'all-lessonfiles':
                 self.m_ui.display_html(self.lessonfile_manager.m_htmldoc)
@@ -170,4 +246,3 @@ code to handle situations like this.)"""
         if soundcard.synth:
             soundcard.synth.close()
 
-
