@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ class Teacher(abstract.LessonbasedTeacher):
     CORRECT = 1
     ALL_CORRECT = 2
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app, const.USE_CHORD)
+        abstract.LessonbasedTeacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.ChordLessonfile
         try: # the lessonfile might contain errors.
             self.parse_lessonfile()
@@ -48,75 +48,28 @@ class Teacher(abstract.LessonbasedTeacher):
         """
         assert self.m_P
         if self.get_bool('config/picky_on_new_question') \
-           and (not self.q_status in (const.QSTATUS_NO, const.QSTATUS_SOLVED)):
+           and (not self.q_status in (const.QSTATUS_NO, const.QSTATUS_SOLVED,
+                                      const.QSTATUS_GIVE_UP)):
            return self.ERR_PICKY
         self.m_P.select_random_question()
-        self.m_correct = [self.m_P.get_chordtype() == -1,
+        self.m_correct = [self.m_P.get_cname() == -1,
                           self.m_P.get_inversion() == -1,
                           self.m_P.get_toptone() == -1]
         self.q_status = const.QSTATUS_NEW
         return self.OK
-    def _generate_question_vector(self):
-        if self.get_bool('override_default_instrument'):
-            instr_low = self.get_int('lowest_instrument')
-            instr_low_vel = self.get_int('lowest_instrument_velocity')
-            instr_middle = self.get_int('middle_instrument')
-            instr_middle_vel = self.get_int('middle_instrument_velocity')
-            instr_high = self.get_int('highest_instrument')
-            instr_high_vel = self.get_int('highest_instrument_velocity')
-        else:
-            instr_low = instr_middle = instr_high \
-                        = self.get_int('config/preferred_instrument')
-            instr_low_vel = instr_middle_vel = instr_high_vel \
-                         = self.get_int('config/preferred_instrument_velocity')
-        m = map(string.strip, string.split(self.m_P.get_music()))
-        v = []
-        for x in m:
-            v.append([x, instr_middle, instr_middle_vel])
-        v[0][1] = instr_low
-        v[0][2] = instr_low_vel
-        v[-1][1] = instr_high
-        v[-1][2] = instr_high_vel
-        return v
     def give_up(self):
-        self.q_status = const.QSTATUS_SOLVED
-    def play_question(self):
-        if self.q_status == const.QSTATUS_NO:
-            return
-        v = self._generate_question_vector()
-        m = soundcard.Track()
-        m.set_bpm(self.get_int('config/default_bpm'))
-        for x in range(len(v)):
-            m.set_patch(x, v[x][1])
-            m.start_note(x, mpd.notename_to_int(v[x][0]), v[x][2])
-        for x in range(len(v)):
-            if x == 0:
-                m.notelen_time(4)
-                m.stop_note(x, mpd.notename_to_int(v[x][0]), v[x][2])
-            else:
-                m.stop_note(x, mpd.notename_to_int(v[x][0]), v[x][2])
-        soundcard.synth.play_track(m)
-    def play_question_arpeggio(self):
-        if self.q_status == const.QSTATUS_NO:
-            return
-        v = self._generate_question_vector()
-        m = soundcard.Track()
-        m.set_bpm(self.get_int('config/arpeggio_bpm'))
-        for x in range(len(v)):
-            m.set_patch(0, v[x][1])
-            m.note(4, 0, mpd.notename_to_int(v[x][0]), v[x][2])
-        soundcard.synth.play_track(m)
+        self.q_status = const.QSTATUS_GIVE_UP
     def guess_type(self, t):
         """
         GUI guarantees that this method will not be called after it has
         been guessed correct once.
-        
+
         return 0 if this was wrong guess.
         return CORRECT if this question is correct.
         return ALL_CORRECT if all parts of the question is correct.
         """
         assert self.q_status == const.QSTATUS_NEW
-        if t == self.m_P.get_chordtype():
+        if t == self.m_P.get_cname():
             self.m_correct[0] = 1
             if self.m_correct == [1, 1, 1]:
                self.q_status = const.QSTATUS_SOLVED
@@ -175,7 +128,7 @@ class Gui(abstract.LessonbasedGui):
         hbox.set_spacing(gnome.ui.PAD)
 
         table = gtk.Table(5, 5, 0)
-        hbox.pack_start(table, gtk.FALSE)
+        hbox.pack_start(table, False)
         hsep = gtk.HSeparator()
         table.attach(hsep, 0, 5, 1, 2, xoptions=gtk.FILL,
                      yoptions=0, ypadding=gnome.ui.PAD_SMALL)
@@ -220,10 +173,10 @@ class Gui(abstract.LessonbasedGui):
         self.g_new = gu.bButton(self.action_area, _("_New chord"),
                                 self.new_question)
         self.g_repeat = gu.bButton(self.action_area, _("_Repeat"),
-                                lambda _o, self=self: self.m_t.play_question())
+                                lambda _o: self.m_t.m_P.play_question())
         self.g_repeat_arpeggio = gu.bButton(self.action_area,
-              _("Repeat _arpeggio"),
-              lambda _o, self=self: self.m_t.play_question_arpeggio())
+              _("Repeat _arpeggio"), 
+              lambda _o: self.m_t.m_P.play_question_arpeggio())
         self.g_give_up = gu.bButton(self.action_area, _("_Give up"),
                                     self.give_up)
         self.practise_box.show_all()
@@ -235,9 +188,23 @@ class Gui(abstract.LessonbasedGui):
             self.m_t, self.g_win, self.update_gui_after_lessonfile_change)
         self.g_lessonfile_selector.show()
         self.config_box.pack_start(self.g_lessonfile_selector)
+
+        hbox = gu.bHBox(self.config_box)
+        label = gtk.Label(_("Random transpose:"))
+        label.show()
+        hbox.pack_start(label)
+        self.g_random_transpose = gtk.Entry()
+        self.g_random_transpose.set_editable(False)
+        self.g_random_transpose.show()
+        hbox.pack_start(self.g_random_transpose)
+
+        button = gtk.Button(_("Change ..."))
+        button.show()
+        hbox.pack_start(button)
+
         self.g_instrument_configurator  \
               = widgets.InstrumentConfigurator(self.m_exname, 3)
-        self.config_box.pack_start(self.g_instrument_configurator, gtk.FALSE)
+        self.config_box.pack_start(self.g_instrument_configurator, False)
         self.g_instrument_configurator.show()
         self.update_gui_after_lessonfile_change()
     def update_answer_buttons(self, obj=None):
@@ -248,8 +215,10 @@ class Gui(abstract.LessonbasedGui):
         if self.m_t.m_P:
             for t in self.m_t.m_P.m_chord_types.keys():
                 b = gtk.Button(self.m_t.m_P.m_chord_types[t])
-                b.connect('clicked', self.on_type, t)
-                self.g_chordtype_box.pack_start(b, gtk.FALSE)
+                b.set_data('type', t)
+                b.connect('clicked', self.on_type)
+                b.connect('button_release_event', self.on_type)
+                self.g_chordtype_box.pack_start(b, False)
                 b.show()
             v = self.m_t.m_P.m_inversions
             v.sort()
@@ -259,81 +228,188 @@ class Gui(abstract.LessonbasedGui):
                 else:
                     s = _("%i. inversion") % x
                 b = gtk.Button(s)
-                b.connect('clicked', self.on_inversion, x)
-                self.g_inversion_box.pack_start(b, gtk.FALSE)
+                b.set_data('inversion', x)
+                b.connect('clicked', self.on_inversion)
+                b.connect('button_release_event', self.on_inversion)
+                self.g_inversion_box.pack_start(b, False)
                 b.show()
             v = self.m_t.m_P.m_toptones
             v.sort()
             for x in v:
                 b = gtk.Button(str(x))
-                b.connect('clicked', self.on_toptone, x)
-                self.g_toptone_box.pack_start(b, gtk.FALSE)
+                b.set_data('toptone', x)
+                b.connect('clicked', self.on_toptone)
+                b.connect('button_release_event', self.on_toptone)
+                self.g_toptone_box.pack_start(b, False)
                 b.show()
     def update_gui_after_lessonfile_change(self):
         self.g_music_displayer.clear()
         if self.m_t.m_P:
-            self.g_new.set_sensitive(gtk.TRUE)
+            self.g_new.set_sensitive(True)
         else:
-            self.g_new.set_sensitive(gtk.FALSE)
-        self.g_repeat.set_sensitive(gtk.FALSE)
-        self.g_repeat_arpeggio.set_sensitive(gtk.FALSE)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+            self.g_new.set_sensitive(False)
+        self.g_repeat.set_sensitive(False)
+        self.g_repeat_arpeggio.set_sensitive(False)
+        self.g_give_up.set_sensitive(False)
         self.update_answer_buttons()
+        self.g_type_status.set_text('')
+        self.g_inversion_status.set_text('')
+        self.g_toptone_status.set_text('')
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
-    def on_type(self, button, t):
+    def on_type(self, button, event=None):
+        if event == None:
+            self.on_type_left_clicked(button)
+        elif event.button == 3:
+            self.on_type_right_clicked(button)
+    def on_type_left_clicked(self, button):
         if self.m_t.q_status in (const.QSTATUS_NO, const.QSTATUS_GIVE_UP)\
           or self.m_t.m_correct[0]:
             return
-        g = self.m_t.guess_type(t)
+        g = self.m_t.guess_type(button.get_data('type'))
         if g:
             self.g_type_status.set_text(_("Correct"))
             for b in self.g_chordtype_box.get_children():
-                if b != button:
-                    b.set_sensitive(gtk.FALSE)
+                if b == button:
+                    b.get_children()[0].set_name("Bold")
             if g == self.m_t.ALL_CORRECT:
                 self.all_guessed_correct()
         else:
             self.g_type_status.set_text(_("Wrong"))
         if self.m_t.m_correct == [1, 1, 1]:
             self.show_answer()
-            self.g_new.set_sensitive(gtk.TRUE)
+            self.g_new.set_sensitive(True)
             self.g_new.grab_focus()
-            self.g_give_up.set_sensitive(gtk.FALSE)
-    def on_inversion(self, button, inversion):
+            self.g_give_up.set_sensitive(False)
+    def on_type_right_clicked(self, button):
+        #if not self.m_t.ok_to_right_click_type(): #FIXME
+        #    return 
+        if not self.m_t.m_P.has_question():
+            return
+        if self.m_t.m_P.get_toptone() == -1 \
+                and self.m_t.m_P.get_inversion() == -1:
+            if self.m_t.m_P.get_question().has_key('set'):
+                for question in self.m_t.m_P.m_questions:
+                    if question['set'] == self.m_t.m_P.get_question()['set'] \
+                        and question.get_cname() == button.get_data('type'):
+                        self.m_t.m_P.play_question(question)
+                        return
+            else:
+                for question in self.m_t.m_P.m_questions:
+                    if question.get_cname() == button.get_data('type'):
+                        self.m_t.m_P.play_question(question)
+                        return
+        else:
+            #Try for exact match
+            for question in self.m_t.m_P.m_questions:
+                if  question.get_toptone() != self.m_t.m_P.get_toptone():
+                    continue
+                if question.get_inversion() != self.m_t.m_P.get_inversion():
+                    continue
+                if question.get_cname() == button.get_data('type'):
+                    self.m_t.m_P.play_question(question)
+                    return
+        # try to match, ignoring toptone
+        for question in self.m_t.m_P.m_questions:
+            if question.get_inversion() != self.m_t.m_P.get_inversion():
+                continue
+            if question.get_cname() == button.get_data('type'):
+                self.m_t.m_P.play_question(question)
+                return
+        # match if only type matches.
+        for question in self.m_t.m_P.m_questions:
+            if question.get_cname() == button.get_data('type'):
+                self.m_t.m_P.play_question(question)
+                return
+    def on_inversion(self, button, event=None):
+        if event == None:
+            self.on_inversion_left_clicked(button)
+        elif event.button == 3:
+            self.on_inversion_right_clicked(button)
+    def on_inversion_left_clicked(self, button):
         if self.m_t.q_status in (const.QSTATUS_NO, const.QSTATUS_GIVE_UP) \
           or self.m_t.m_correct[1]:
             return
-        if self.m_t.guess_inversion(inversion):
+        if self.m_t.guess_inversion(button.get_data('inversion')):
             self.g_inversion_status.set_text(_("Correct"))
             for b in self.g_inversion_box.get_children():
-                if b != button:
-                    b.set_sensitive(gtk.FALSE)
+                if b == button:
+                    b.get_children()[0].set_name("Bold")
         else:
             self.g_inversion_status.set_text(_("Wrong"))
         if self.m_t.m_correct == [1, 1, 1]:
             self.show_answer()
-            self.g_new.set_sensitive(gtk.TRUE)
+            self.g_new.set_sensitive(True)
             self.g_new.grab_focus()
-            self.g_give_up.set_sensitive(gtk.FALSE)
-    def on_toptone(self, button, toptone):
+            self.g_give_up.set_sensitive(False)
+    def on_inversion_right_clicked(self, button):
+        """
+        First we try to find a chord with the same type and toptone as
+        the question, and with toptone as in button.get_data('toptone').
+
+        Second best is to ignore inversion and find a chord where chord type
+        is the same as the questions, and with toptone as
+        button.get_data('toptone')
+
+        """
+        if not self.m_t.m_P.has_question():
+            return
+        # first we try to get an exact match
+        for question in self.m_t.m_P.m_questions:
+            if question.get_toptone() != -1 \
+                    and question.get_toptone() != self.m_t.m_P.get_toptone():
+                continue
+            if question.get_cname() == self.m_t.m_P.get_cname() \
+                  and question.get_inversion() == button.get_data('inversion'):
+                self.m_t.m_P.play_question(question)
+                return
+        # then we tries to match chord type and inversion, ignoring toptone
+        for question in self.m_t.m_P.m_questions:
+            if question.get_cname() == self.m_t.m_P.get_question().get_cname()\
+                   and question.get_inversion() == button.get_data('inversion'):
+                self.m_t.m_P.play_question(question)
+                return
+    def on_toptone(self, button, event=None):
+        if not event:
+            self.on_toptone_left_clicked(button)
+        elif event.button == 3:
+            self.on_toptone_right_clicked(button)
+    def on_toptone_right_clicked(self, button):
+        if not self.m_t.m_P.has_question():
+            return
+        # first we try to get an exact match
+        for question in self.m_t.m_P.m_questions:
+            if question.get_inversion() != -1 \
+                  and question.get_inversion() != self.m_t.m_P.get_inversion():
+                continue
+            if question.get_cname() == self.m_t.m_P.get_cname() \
+                  and question.get_toptone() == button.get_data('toptone'):
+                self.m_t.m_P.play_question(question)
+                return
+        # then we tries to match chord type and toptone, ignoring inversion
+        for question in self.m_t.m_P.m_questions:
+            if question.get_cname() == self.m_t.m_P.get_question().get_cname()\
+                    and question.get_toptone() == button.get_data('toptone'):
+                self.m_t.m_P.play_question(question)
+                return
+    def on_toptone_left_clicked(self, button):
         if self.m_t.q_status in (const.QSTATUS_NO, const.QSTATUS_GIVE_UP) \
            or self.m_t.m_correct[2]:
             return
-        if self.m_t.guess_toptone(toptone):
+        if self.m_t.guess_toptone(button.get_data('toptone')):
             self.g_toptone_status.set_text(_("Correct"))
             for b in self.g_toptone_box.get_children():
-                if b != button:
-                    b.set_sensitive(gtk.FALSE)
+                if b == button:
+                    b.get_children()[0].set_name("Bold")
         else:
             self.g_toptone_status.set_text(_("Wrong"))
         if self.m_t.m_correct == [1, 1, 1]:
             self.show_answer()
-            self.g_new.set_sensitive(gtk.TRUE)
+            self.g_new.set_sensitive(True)
             self.g_new.grab_focus()
-            self.g_give_up.set_sensitive(gtk.FALSE)
+            self.g_give_up.set_sensitive(False)
     def all_guessed_correct(self):
-        self.g_new.set_sensitive(gtk.TRUE)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+        self.g_new.set_sensitive(True)
+        self.g_give_up.set_sensitive(False)
     def new_question(self, widget=None):
         # if we have no lessonfile, then we have to questions.
         if not self.m_t.m_P:
@@ -342,7 +418,8 @@ class Gui(abstract.LessonbasedGui):
         for button in self.g_chordtype_box.get_children() \
                     + self.g_inversion_box.get_children() \
                     + self.g_toptone_box.get_children():
-            button.set_sensitive(gtk.TRUE)
+            #button.set_sensitive(True)
+            button.get_children()[0].set_name("")
         ##
         try:
             n = self.m_t.new_question()
@@ -350,21 +427,21 @@ class Gui(abstract.LessonbasedGui):
             soundcard.synth.stop()
             self.g_win.display_question_music_error_message(
                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
-            self.g_give_up.set_sensitive(gtk.FALSE)
-            self.g_repeat.set_sensitive(gtk.FALSE)
-            self.g_repeat_arpeggio.set_sensitive(gtk.FALSE)
+            self.g_give_up.set_sensitive(False)
+            self.g_repeat.set_sensitive(False)
+            self.g_repeat_arpeggio.set_sensitive(False)
             self.m_t.q_status = const.QSTATUS_NO
         else:
             if n == Teacher.ERR_PICKY:
                 print "picky!"
             else:
                 self.g_music_displayer.clear()
-                self.m_t.play_question()
-                self.g_give_up.set_sensitive(gtk.TRUE)
-                self.g_repeat.set_sensitive(gtk.TRUE)
+                self.m_t.m_P.play_question()
+                self.g_give_up.set_sensitive(True)
+                self.g_repeat.set_sensitive(True)
                 if self.get_bool('config/picky_on_new_question'):
-                    self.g_new.set_sensitive(gtk.FALSE)
-                self.g_repeat_arpeggio.set_sensitive(gtk.TRUE)
+                    self.g_new.set_sensitive(False)
+                self.g_repeat_arpeggio.set_sensitive(True)
                 self.g_type_status.set_text('')
                 self.g_inversion_status.set_text('')
                 self.g_toptone_status.set_text('')
@@ -376,10 +453,10 @@ class Gui(abstract.LessonbasedGui):
     def on_end_practise(self):
         self.m_t.end_practise()
         self.g_music_displayer.clear()
-        self.g_new.set_sensitive(gtk.TRUE)
-        self.g_repeat.set_sensitive(gtk.FALSE)
-        self.g_repeat_arpeggio.set_sensitive(gtk.FALSE)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+        self.g_new.set_sensitive(True)
+        self.g_repeat.set_sensitive(False)
+        self.g_repeat_arpeggio.set_sensitive(False)
+        self.g_give_up.set_sensitive(False)
         self.g_type_status.set_text('')
         self.g_inversion_status.set_text('')
         self.g_toptone_status.set_text('')
@@ -387,7 +464,7 @@ class Gui(abstract.LessonbasedGui):
         if self.m_t.q_status == const.QSTATUS_NEW:
             self.m_t.give_up()
             self.show_answer()
-            self.g_type_status.set_text(self.m_t.m_P.get_chordtype())
+            self.g_type_status.set_text(self.m_t.m_P.m_chord_types[self.m_t.m_P.get_cname()])
             i = self.m_t.m_P.get_inversion()
             if i == 0:
                 self.g_inversion_status.set_text(_("root position"))
@@ -396,14 +473,29 @@ class Gui(abstract.LessonbasedGui):
             i = self.m_t.m_P.get_toptone()
             if i != -1:
                 self.g_toptone_status.set_text("%i" % i)
-            self.g_new.set_sensitive(gtk.TRUE)
-            self.g_give_up.set_sensitive(gtk.FALSE)
-            for b in self.g_chordtype_box.get_children() \
-                   + self.g_inversion_box.get_children() \
-                   + self.g_toptone_box.get_children():
-                b.set_sensitive(gtk.FALSE)
+            self.g_new.set_sensitive(True)
+            self.g_give_up.set_sensitive(False)
+            for button in self.g_chordtype_box.get_children():
+                if button.get_data('type') == self.m_t.m_P.get_cname():
+                    button.get_children()[0].set_name('Bold')
+                else:
+                    button.get_children()[0].set_name('')
+            for button in self.g_inversion_box.get_children():
+                if button.get_data('inversion') == self.m_t.m_P.get_inversion():
+                    button.get_children()[0].set_name('Bold')
+                else:
+                    button.get_children()[0].set_name('')
+            for button in self.g_toptone_box.get_children():
+                if button.get_data('toptone') == self.m_t.m_P.get_toptone():
+                    button.get_children()[0].set_name('Bold')
+                else:
+                    button.get_children()[0].set_name('')
     def show_answer(self):
-        clef = mpd.select_clef(self.m_t.m_P.get_music())
         fontsize = self.get_int('config/feta_font_size=20')
-        self.g_music_displayer.display(r"\staff{\clef %s <%s>}" % (clef, self.m_t.m_P.get_music()), fontsize)
+        if self.m_t.m_P.header.musicformat == 'chord':
+            clef = mpd.select_clef(self.m_t.m_P.get_music_as_notename_string())
+            self.g_music_displayer.display(r"\staff{\clef %s <%s>}" % (clef, self.m_t.m_P.get_music_as_notename_string()), fontsize)
+        else:
+            assert self.m_t.m_P.header.musicformat == 'satb'
+            self.g_music_displayer.display(self.m_t.m_P.get_music(), fontsize)
 
