@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ class Teacher(abstract.LessonbasedTeacher):
     ERR_PICKY = 1
     #UGH should we do this here
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app, const.USE_CHORD_VOICING)
+        abstract.LessonbasedTeacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.ChordLessonfile
         try: # the lessonfile might contain errors.
             self.parse_lessonfile()
@@ -54,20 +54,6 @@ class Teacher(abstract.LessonbasedTeacher):
             self.m_P.select_random_question()
             self.q_status = const.QSTATUS_NEW
             return Teacher.OK
-    def play_question(self):
-        if self.q_status == const.QSTATUS_NO:
-            return
-        mpd.play_music(r"\staff{ <%s> }" % self.m_P.get_music(),
-                       self.m_P.get_tempo(),
-                       cfg.get_int('config/preferred_instrument'),
-                       cfg.get_int('config/preferred_instrument_velocity'))
-    def play_question_arpeggio(self):
-        if self.q_status == const.QSTATUS_NO:
-            return
-        mpd.play_music(r"\staff{ %s }" % self.m_P.get_music(),
-                       cfg.get_int('config/arpeggio_bpm'),
-                       cfg.get_int('config/preferred_instrument'),
-                       cfg.get_int('config/preferred_instrument_velocity'))
     def guess_chordtype(self, t):
         """
         return 1 if correct, None if not.
@@ -85,7 +71,7 @@ class Teacher(abstract.LessonbasedTeacher):
         if voicing wrong: const.QSTATUS_VOICING_WRONG
         """
         if self.q_status in (const.QSTATUS_NEW, const.QSTATUS_TYPE_WRONG):
-            if t == self.m_P.get_chordtype():
+            if t == self.m_P.get_cname():
                 self.q_status = const.QSTATUS_TYPE_SOLVED
                 return 1
             else:
@@ -96,8 +82,10 @@ class Teacher(abstract.LessonbasedTeacher):
         return 1 if correct, None if not.
         Gui should not call this function if the question is already solved.
         """
+        v = self.m_P.get_music_as_notename_list()
+        v.sort(mpd.compare_notenames)
         question_i = []
-        for n in self.m_P.get_music().split():
+        for n in v:
             while n[-1] in ",'":
                 n = n[:-1]
             question_i.append(mpd.notename_to_int(n))
@@ -124,7 +112,7 @@ class Gui(abstract.LessonbasedGui):
         ###############
         self.practise_box.set_spacing(gnome.ui.PAD)
 
-        hbox = gu.bHBox(self.practise_box, gtk.TRUE, gtk.TRUE)
+        hbox = gu.bHBox(self.practise_box, True, True)
         hbox.set_spacing(gnome.ui.PAD)
         ##################
         # chordtype frame 
@@ -139,7 +127,7 @@ class Gui(abstract.LessonbasedGui):
         # stacking frame
         #################
         self.g_stacking_frame = gtk.Frame(_("Click to stack in the correct order"))
-        self.g_stacking_frame.set_sensitive(gtk.FALSE)
+        self.g_stacking_frame.set_sensitive(False)
         hbox.pack_start(self.g_stacking_frame)
         vbox = gtk.VBox()
         vbox.set_border_width(gnome.ui.PAD_SMALL)
@@ -152,16 +140,16 @@ class Gui(abstract.LessonbasedGui):
         t.attach(self.g_answer, 1, 2, 0, 1, gtk.EXPAND|gtk.FILL)
         self.g_redo = gtk.Button("<<<")
         self.g_redo.connect('clicked', lambda o, self=self: self.fill_stacking_frame())
-        vbox.pack_end(self.g_redo, gtk.FALSE, gtk.FALSE)
+        vbox.pack_end(self.g_redo, False, False)
 
         self.g_flashbar = gu.FlashBar()
-        self.practise_box.pack_start(self.g_flashbar, gtk.FALSE)
+        self.practise_box.pack_start(self.g_flashbar, False)
 
         self.g_new = gu.bButton(self.action_area, _("_New chord"),
                                       self.new_question)
         self.g_repeat = gu.bButton(self.action_area, _("_Repeat"),
-                 lambda _o, self=self: self.m_t.play_question())
-        self.g_repeat_arpeggio = gu.bButton(self.action_area, _("Repeat _arpeggio"), lambda _o, self=self: self.m_t.play_question_arpeggio())
+                 lambda _o: self.m_t.m_P.play_question())
+        self.g_repeat_arpeggio = gu.bButton(self.action_area, _("Repeat _arpeggio"), lambda _o: self.m_t.m_P.play_question_arpeggio())
         self.g_give_up = gu.bButton(self.action_area, _("_Give up"), lambda _o, self=self: self.give_up())
         self.practise_box.show_all()
         ##############
@@ -183,36 +171,37 @@ class Gui(abstract.LessonbasedGui):
             soundcard.synth.stop()
             self.g_win.display_question_music_error_message(
                self.m_t.m_P._idx, self.get_string('lessonfile'), e)
-            self.g_give_up.set_sensitive(gtk.FALSE)
-            self.g_repeat.set_sensitive(gtk.FALSE)
-            self.g_repeat_arpeggio.set_sensitive(gtk.FALSE)
+            self.g_give_up.set_sensitive(False)
+            self.g_repeat.set_sensitive(False)
+            self.g_repeat_arpeggio.set_sensitive(False)
             self.m_t.q_status = const.QSTATUS_NO
         else:
             if g == Teacher.OK:
-                self.g_give_up.set_sensitive(gtk.TRUE)
-                self.g_repeat.set_sensitive(gtk.TRUE)
-                self.g_repeat_arpeggio.set_sensitive(gtk.TRUE)
+                self.g_give_up.set_sensitive(True)
+                self.g_repeat.set_sensitive(True)
+                self.g_repeat_arpeggio.set_sensitive(True)
                 self.g_new.set_sensitive(
                     not self.get_bool('config/picky_on_new_question'))
                 self.clear_stacking_frame()
-                self.g_stacking_frame.set_sensitive(gtk.FALSE)
+                self.g_stacking_frame.set_sensitive(False)
                 for c in self.g_chordtype_box.get_children():
-                    c.set_sensitive(gtk.TRUE)
-                self.m_t.play_question()
+                    c.set_sensitive(True)
+                self.m_t.m_P.play_question()
                 self.g_flashbar.flash(_("Identify chord type"))
                 self.g_chordtype_box.get_children()[0].grab_focus()
             elif g == Teacher.ERR_PICKY:
                 self.g_flashbar.flash(_("You have to solve this question first."))
     def update_gui_after_lessonfile_change(self, *v):
         if self.m_t.m_P:
-            self.g_new.set_sensitive(gtk.TRUE)
+            self.g_new.set_sensitive(True)
             self.fill_chordtype_box()
         else:
-            self.g_new.set_sensitive(gtk.FALSE)
-        self.g_repeat.set_sensitive(gtk.FALSE)
-        self.g_repeat_arpeggio.set_sensitive(gtk.FALSE)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+            self.g_new.set_sensitive(False)
+        self.g_repeat.set_sensitive(False)
+        self.g_repeat_arpeggio.set_sensitive(False)
+        self.g_give_up.set_sensitive(False)
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
+        self.clear_stacking_frame()
     def clear_stacking_frame(self):
         for c in self.g_source.get_children() + self.g_answer.get_children():
             c.destroy()
@@ -220,28 +209,28 @@ class Gui(abstract.LessonbasedGui):
         """
         Create the buttons in stacking frame.
         """
-        self.g_redo.set_sensitive(gtk.TRUE)
-        self.g_stacking_frame.set_sensitive(gtk.TRUE)
+        self.g_redo.set_sensitive(True)
+        self.g_stacking_frame.set_sensitive(True)
         self.m_answer = []
         self.clear_stacking_frame()
-        v = self.m_t.m_P.get_music().split()
+        v = self.m_t.m_P.get_music_as_notename_list()
         v.sort()
         for n in v:
             nn = mpd.MusicalPitch.new_from_notename(n)
             b = gtk.Button(nn.get_user_notename())
             b.connect('clicked', self.on_notebutton_clicked, nn.get_notename(), nn.get_user_notename())
-            self.g_source.pack_end(b, gtk.FALSE, gtk.FALSE)
+            self.g_source.pack_end(b, False, False)
             b.show()
         self.g_source.get_children()[0].grab_focus()
     def give_up(self, v=None):
         self.m_t.give_up()
-        self.g_give_up.set_sensitive(gtk.FALSE)
-        self.g_new.set_sensitive(gtk.TRUE)
+        self.g_give_up.set_sensitive(False)
+        self.g_new.set_sensitive(True)
         self.g_new.grab_focus()
-        self.set_chordtype_frame_status_solved(self.m_t.m_P.get_chordtype())
+        self.set_chordtype_frame_status_solved(self.m_t.m_P.get_cname())
         self.clear_stacking_frame()
-        self.g_stacking_frame.set_sensitive(gtk.TRUE)
-        self.g_redo.set_sensitive(gtk.FALSE)
+        self.g_stacking_frame.set_sensitive(True)
+        self.g_redo.set_sensitive(False)
         self.show_music()
     def on_chordtype_clicked(self, btn, t):
         if self.m_t.q_status == const.QSTATUS_NO:
@@ -261,16 +250,16 @@ class Gui(abstract.LessonbasedGui):
         newb.show()
         btn.destroy()
         self.m_answer.append(n)
-        self.g_answer.pack_end(newb, gtk.FALSE, gtk.FALSE)
+        self.g_answer.pack_end(newb, False, False)
         if not self.g_source.get_children():
             # no children mean that the user has finished answering
             if self.m_t.guess_voicing(self.m_answer):
                 self.g_flashbar.flash(_("Correct"))
                 self.show_music()
-                self.g_new.set_sensitive(gtk.TRUE)
+                self.g_new.set_sensitive(True)
                 self.g_new.grab_focus()
-                self.g_give_up.set_sensitive(gtk.FALSE)
-                self.g_redo.set_sensitive(gtk.FALSE)
+                self.g_give_up.set_sensitive(False)
+                self.g_redo.set_sensitive(False)
             else:
                 self.g_flashbar.flash(_("Wrong"))
                 self.g_redo.grab_focus()
@@ -282,14 +271,16 @@ class Gui(abstract.LessonbasedGui):
         self.g_source.pack_start(md)
         md.show()
         md.display(r"\staff{ \clef %s < %s >}" % (
-                mpd.select_clef(self.m_t.m_P.get_music()),
-                self.m_t.m_P.get_music()), 20)
+                mpd.select_clef(self.m_t.m_P.get_music_as_notename_string()),
+                self.m_t.m_P.get_music_as_notename_string()), 20)
         # display the notenames on the buttons with octave info
-        for n in self.m_t.m_P.get_music().split():
+        v = self.m_t.m_P.get_music_as_notename_list()
+        v.sort(mpd.compare_notenames)
+        for n in v:
             b = gtk.Button(mpd.MusicalPitch.new_from_notename(n).get_user_octave_notename())
             b.get_children()[0].set_use_markup(1)
             b.show()
-            self.g_answer.pack_end(b, gtk.FALSE, gtk.FALSE)
+            self.g_answer.pack_end(b, False, False)
     def fill_chordtype_box(self):
         for x in self.g_chordtype_box.get_children():
             x.destroy()
@@ -297,7 +288,7 @@ class Gui(abstract.LessonbasedGui):
             for t in self.m_t.m_P.m_chord_types.keys():
                 b = gtk.Button(self.m_t.m_P.m_chord_types[t])
                 b.set_data('chordtype', t)
-                self.g_chordtype_box.pack_start(b, gtk.FALSE)
+                self.g_chordtype_box.pack_start(b, False)
                 b.connect('clicked', self.on_chordtype_clicked, t)
                 b.show()
     def set_chordtype_frame_status_solved(self, t):
@@ -309,10 +300,10 @@ class Gui(abstract.LessonbasedGui):
             self.g_flashbar.flash(_("Click 'New chord' to begin.")))
         self.fill_chordtype_box()
         self.clear_stacking_frame()
-        self.g_stacking_frame.set_sensitive(gtk.FALSE)
+        self.g_stacking_frame.set_sensitive(False)
     def on_end_practise(self):
         self.m_t.end_practise()
-        self.g_new.set_sensitive(gtk.TRUE)
-        self.g_repeat.set_sensitive(gtk.FALSE)
-        self.g_repeat_arpeggio.set_sensitive(gtk.FALSE)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+        self.g_new.set_sensitive(True)
+        self.g_repeat.set_sensitive(False)
+        self.g_repeat_arpeggio.set_sensitive(False)
+        self.g_give_up.set_sensitive(False)
