@@ -1,5 +1,5 @@
 # -*- coding: iso-8859-1 -*-
-# GNU Solfege - eartraining for GNOME
+# GNU Solfege - ear training for GNOME
 # Copyright (C) 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
@@ -40,6 +40,12 @@ assignmentlist peek: 'NAME' '='
 # P singchord-1 sparer jeg ikke noe p  ha en peek2_type(t1, t2)
 # som tester de to neste token.
 
+if __name__ == "__main__" or __name__ == "dataparser":
+    import sys
+    sys.path.append("src")
+    import i18n
+    i18n.setup_srcdir()
+
 import sys
 import os, os.path
 import gettext
@@ -56,7 +62,7 @@ NEW_re = re.compile("""(?:
                         (-?\d+)| #integer
                         (\"\"\"(.*?)\"\"\")| #multiline string
                         ("(.*?)")| #string
-                        (\w[\w-]*) #name
+                        (\w[\[\]\w-]*) #name
                 )""",
                       re.VERBOSE|re.MULTILINE|re.DOTALL|re.UNICODE)
 
@@ -78,13 +84,54 @@ lastindex_to_group = {LI_INTEGER: 3,
                      LI_NAME: 8,
                     }
 
+class _TranslatedString:
+    def __init__(self, i18n, cname):
+        self.i18n = i18n
+        self.cname = cname
+
+def dataparser_i18n_func(s):
+    return _TranslatedString(_(s), s)
 
 def get_translated_string(dict, name):
     for n in i18n.langs():
-        if dict.has_key("%s(%s)" % (name, n)):
-            return dict["%s(%s)" % (name, n)]
+        if dict.has_key("%s[%s]" % (name, n)):
+            return dict["%s[%s]" % (name, n)]
     return dict[name]
 
+class Question(dict):
+    def get_toptone(self):
+        if self.has_key('toptone'):
+            return self['toptone']
+        return -1
+    def get_inversion(self):
+        if self.has_key('inversion'):
+            return self['inversion']
+        return -1
+    def get_tempo(self):
+        return self['tempo']
+    def get_cname(self):
+        """
+        Return the untranslated question name
+        """
+        if self.has_key('C-name'):
+            return self['C-name']
+        return self['name']
+    def get_name(self):
+        """
+        Return the translated name of the question, or the untranslated
+        if not available. name[no]="blabla" will be used before
+        name=_("blabla") if both are available.
+        """
+        for n in i18n.langs():
+            if self.has_key("name[%s]" % n):
+                return self["name[%s]" % n]
+        if self.has_key("name"):
+            return self["name"]
+        if self.has_key("name"):
+            return self["C-name"]
+        return "[no name]"
+    def get_music(self):
+        return self['m_lessonfile'].get_music_of_question(self)
 
 class DataparserException(Exception):
     def __init__(self, filename, lexer):
@@ -139,7 +186,8 @@ class UnableToTokenizeException(DataparserException):
 
 
 class Lexer:
-    def __init__(self, src):
+    def __init__(self, src, parser):
+        self.m_parser = parser
         r = re.compile("#.*?coding\s*[:=]\s*([\w_.-]+)")
         m = r.match(src)
         if m:
@@ -226,8 +274,7 @@ class Dataparser:
         """
         self.m_filename = filename
         infile = file(filename, 'r')
-        self._lexer = Lexer(infile.read())
-        self._lexer.m_parser = self
+        self._lexer = Lexer(infile.read(), self)
         infile.close()
         self.reserved_words = ('_', 'question', 'header')
         self.prog()
@@ -266,7 +313,7 @@ class Dataparser:
         self.header = {}
         ifile = file(os.path.join(os.path.dirname(self.m_filename),
                                           filename), 'r')
-        self._lexer = Lexer(ifile.read())
+        self._lexer = Lexer(ifile.read(), self)
         ifile.close()
         self.prog()
         self._lexer = old_lexer
@@ -285,7 +332,11 @@ class Dataparser:
         self._lexer.scan_any()#('=')
         faktorlist = self.faktorlist()
         if len(faktorlist) == 1:
-            self.context[name] = faktorlist[0]
+            if isinstance(faktorlist[0], _TranslatedString):
+                self.context[name] = faktorlist[0].i18n
+                self.context["C-%s"%name] = faktorlist[0].cname
+            else:
+                self.context[name] = faktorlist[0]
         else:
             self.context[name] = faktorlist
     def faktor(self):
@@ -359,7 +410,7 @@ class Dataparser:
         if name == 'header':
             self.context = self.header
         elif name == 'question':
-            self.questions.append({})
+            self.questions.append(Question())
             self.context = self.questions[-1]
         else:
             raise SyntaxError(self,  "Unknown block name '%s'" % name)
@@ -394,7 +445,7 @@ def test_tokenizer():
         print "Give the file to parse as command line argument."
         sys.exit(-1)
     infile = file(sys.argv[1], 'r')
-    lexer = Lexer(infile)
+    lexer = Lexer(infile, None)
     infile.close()
     i=0
     for t in lexer.m_tokens:
@@ -449,7 +500,7 @@ def main():
         t1 = time.clock()
         for x in xrange(300):
             f = file(sys.argv[-1], 'r')
-            L = Lexer(f.read())
+            L = Lexer(f.read(), None)
             f.close()
         print time.clock()-t1
         #print p.questions
@@ -475,7 +526,7 @@ def main():
                   'accidentals': 'accidentals',
                   'key': 'key',
                   'semitones': 'semitones',
-                  'tempo': (60, 4)}, {'_': _})
+                  'tempo': (60, 4)}, {'_': dataparser_i18n_func})
            print fn
            p.parse_file(fn)
 
