@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ class Teacher(abstract.LessonbasedTeacher):
                questions in the same file might be useable.
     """
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app, const.USE_DICTATION)
+        abstract.LessonbasedTeacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.DictationLessonfile
         try:
             self.parse_lessonfile()
@@ -44,6 +44,7 @@ class Teacher(abstract.LessonbasedTeacher):
         else:
             #to please abstract.LessonParser
             self.q_status = const.QSTATUS_NEW
+            self.m_P.select_first()
 
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
@@ -51,7 +52,7 @@ class Gui(abstract.LessonbasedGui):
         ################
         # practise_box #
         ################
-        self.g_question_title = gu.bLabel(self.practise_box, "")
+        self.g_question_title = gu.bLabel(self.practise_box, "", False, False)
 
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.g_music_displayer.show()
@@ -59,19 +60,19 @@ class Gui(abstract.LessonbasedGui):
         ###############
         # action_area #
         ###############
-        self.g_partbox = gu.bHBox(self.practise_box, gtk.FALSE)
+        self.g_partbox = gu.bHBox(self.practise_box, False)
         b = gtk.Button(stock='gtk-go-back')
         b.connect('clicked', self.select_previous)
         b.show()
         if configureoutput.WITH_GNOME:
             b.get_children()[0].get_children()[0].get_children()[1].hide()
-        self.action_area.pack_start(b, gtk.FALSE)
+        self.action_area.pack_start(b, False)
         b = gtk.Button(stock='gtk-go-forward')
         b.show()
         b.connect('clicked', self.select_next)
         if configureoutput.WITH_GNOME:
             b.get_children()[0].get_children()[0].get_children()[1].hide()
-        self.action_area.pack_start(b, gtk.FALSE)
+        self.action_area.pack_start(b, False)
         self.g_play = gu.bButton(self.action_area, _("_Play the whole music"),
                                  self.play)
         self.g_show = gu.bButton(self.action_area, _("_Show"), self.show_answer)
@@ -91,13 +92,13 @@ class Gui(abstract.LessonbasedGui):
             self.g_win.display_question_music_error_message(
                 self.m_t.m_P._idx, self.get_string('lessonfile'), e)
             self.m_t.q_status = const.QSTATUS_NO
-            self.g_play.set_sensitive(gtk.FALSE)
-            self.g_show.set_sensitive(gtk.FALSE)
+            self.g_play.set_sensitive(False)
+            self.g_show.set_sensitive(False)
             self.g_music_displayer.clear()
         else:
             self.m_t.q_status = const.QSTATUS_NEW
-            self.g_play.set_sensitive(gtk.TRUE)
-            self.g_show.set_sensitive(gtk.TRUE)
+            self.g_play.set_sensitive(True)
+            self.g_show.set_sensitive(True)
         self._update()
     def select_next(self, widget):
         self.m_t.m_P.select_next()
@@ -107,13 +108,13 @@ class Gui(abstract.LessonbasedGui):
             self.g_win.display_question_music_error_message(
                 self.m_t.m_P._idx, self.get_string('lessonfile'), e)
             self.m_t.q_status = const.QSTATUS_NO
-            self.g_play.set_sensitive(gtk.FALSE)
-            self.g_show.set_sensitive(gtk.FALSE)
+            self.g_play.set_sensitive(False)
+            self.g_show.set_sensitive(False)
             self.g_music_displayer.clear()
         else:
             self.m_t.q_status = const.QSTATUS_NEW
-            self.g_play.set_sensitive(gtk.TRUE)
-            self.g_show.set_sensitive(gtk.TRUE)
+            self.g_play.set_sensitive(True)
+            self.g_show.set_sensitive(True)
         self._update()
     def play(self, widget=None):
         # see Teacher docstring.
@@ -122,7 +123,7 @@ class Gui(abstract.LessonbasedGui):
         if not self.m_t.m_P:
             return
         try:
-            self.m_t.play_question()
+            self.m_t.m_P.play_question()
         except mpd.MpdException, e:
             # since we could not play the new question, it is possible,
             # if the user are fast, that the last question is still playing.
@@ -186,9 +187,9 @@ class Gui(abstract.LessonbasedGui):
                 self.g_partbox.pack_start(btn)
         # q_status is QSTATUS_NO if the question is invalid (from the lessonfile)
         if self.m_t.q_status == const.QSTATUS_NO:
-            self.g_partbox.set_sensitive(gtk.FALSE)
+            self.g_partbox.set_sensitive(False)
         else:
-            self.g_partbox.set_sensitive(gtk.TRUE)
+            self.g_partbox.set_sensitive(True)
     def display_start_of_music(self):
         fontsize = self.get_int('config/feta_font_size=20')
         if self.m_t.m_P.get_clue_music():
@@ -203,22 +204,23 @@ class Gui(abstract.LessonbasedGui):
     def update_gui_after_lessonfile_change(self):
         self.m_t.q_status = const.QSTATUS_NEW
         if self.m_t.m_P:
-            self.action_area.set_sensitive(gtk.TRUE)
+            self.m_t.m_P.select_first()
+            self.action_area.set_sensitive(True)
             try:
                 self.display_start_of_music()
             except mpd.MpdException, e:
                 self.g_win.display_question_music_error_message(
                     self.m_t.m_P._idx, self.get_string('lessonfile'), e)
                 self.m_t.q_status = const.QSTATUS_NO
-                self.g_play.set_sensitive(gtk.FALSE)
-                self.g_show.set_sensitive(gtk.FALSE)
+                self.g_play.set_sensitive(False)
+                self.g_show.set_sensitive(False)
                 self.g_music_displayer.clear()
             else:
-                self.g_play.set_sensitive(gtk.TRUE)
-                self.g_show.set_sensitive(gtk.TRUE)
+                self.g_play.set_sensitive(True)
+                self.g_show.set_sensitive(True)
         else:
             self.g_music_displayer.clear()
-            self.action_area.set_sensitive(gtk.FALSE)
+            self.action_area.set_sensitive(False)
         self._update()
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
     def create_pixmap_button(self):
