@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,13 +31,13 @@ def tLabel(table, x1, x2, y1, y2, text="", xalign=0.0, yalign=0.5, xoptions=gtk.
     table.attach(label, x1, x2, y1, y2, xoptions=xoptions, yoptions=yoptions, xpadding=xpadding, ypadding=ypadding)
     return label
 
-def bLabel(pack_into, label, expand=gtk.TRUE, fill=gtk.TRUE):
+def bLabel(pack_into, label, expand=True, fill=True):
     b = gtk.Label(label)
     b.show()
     pack_into.pack_start(b, expand, fill)
     return b
 
-def bButton(pack_into, label, callback=None, expand=gtk.TRUE, fill=gtk.TRUE):
+def bButton(pack_into, label, callback=None, expand=True, fill=True):
     b = gtk.Button(label)
     b.show()
     if callback:
@@ -78,13 +78,13 @@ def tSpinButton(table, x1, x2, y1, y2,
     table.attach(spin, x1, x2, y1, y2)
     return spin
 
-def bHBox(pack_into, expand=gtk.TRUE, fill=gtk.TRUE, padding=0):
+def bHBox(pack_into, expand=True, fill=True, padding=0):
     b = gtk.HBox()
     b.show()
     pack_into.pack_start(b, expand, fill, padding)
     return b
 
-def bVBox(pack_into, expand=gtk.TRUE, fill=gtk.TRUE, padding=0):
+def bVBox(pack_into, expand=True, fill=True, padding=0):
     b = gtk.VBox()
     pack_into.pack_start(b, expand, fill, padding)
     return b
@@ -137,14 +137,14 @@ class nCombo(gtk.Combo, cfg.ConfigUtils):
         cfg.ConfigUtils.__dict__['__init__'](self, exname)
         self.popdown_strings = popdown_strings
         self.m_name = name
-        self.set_value_in_list(gtk.TRUE, gtk.FALSE)
+        self.set_value_in_list(True, False)
         self.set_popdown_strings(popdown_strings)
         i = self.get_int_with_default(name, -1)
         if i == -1:
             i = popdown_strings.index(default)
         self.entry.set_text(popdown_strings[i])
         self.entry.connect("changed", self.entry_changed)
-        self.entry.set_editable(gtk.FALSE)
+        self.entry.set_editable(False)
         self.show()
     def entry_changed(self, entry):
         self.set_int(self.m_name, self.popdown_strings.index(entry.get_text()))
@@ -162,10 +162,10 @@ class PercussionNameOptionMenu(gtk.OptionMenu, cfg.ConfigUtils):
         if not i:
             i = soundcard.percussionname_to_int(default)
             self.set_int(name, i)
-        self.set_history(i)
+        self.set_history(i-35)
         self.connect("changed", self.entry_changed)
     def entry_changed(self, widget):
-        #UGH value 35 should be taken from soundcard module.
+        #FIXME value 35 should be taken from soundcard module.
         self.set_int(self.m_name, widget.get_history()+35)
 
 
@@ -217,3 +217,55 @@ class FlashBar(gtk.Frame):
         self.__stack = []
         if not self.__timeout:
             self.__label.set_text('')
+
+def hig_dlg_vbox():
+    """a GtkVBox containing as many rows as you wish to have categories
+    inside the control area of the GtkDialog.
+    """
+    vbox = gtk.VBox()
+    vbox.set_spacing(18)
+    vbox.set_border_width(12)
+    return vbox
+
+def hig_category_vbox(title):
+    """
+    Return a tuple of two boxes:
+    box1 -- a box containing everything including the title. Useful
+            if you have to hide a category.
+    box2    The box you should pack your stuff in.
+    """
+    vbox = gtk.VBox()
+    vbox.set_spacing(6)
+    label = gtk.Label('<span weight="bold">%s</span>' % title)
+    label.set_use_markup(True)
+    label.set_alignment(0.0, 0.0)
+    vbox.pack_start(label, False)
+    hbox = gtk.HBox()
+    vbox.pack_start(hbox, False)
+    fill = gtk.Label("    ")
+    hbox.pack_start(fill, False)
+    category_content_vbox = gtk.VBox()
+    hbox.pack_start(category_content_vbox, True)
+    category_content_vbox.set_spacing(6)
+    vbox.show_all()
+    return vbox, category_content_vbox
+
+def hig_label_widget(txt, widget, sizegroup):
+    """
+    Return a box containing a label and a widget, aligned nice
+    as the HIG say we should.
+    """
+    hbox = gtk.HBox()
+    hbox.set_spacing(6)
+    label = gtk.Label(txt)
+    label.set_alignment(0.0, 0.5)
+    if sizegroup:
+        sizegroup.add_widget(label)
+    hbox.pack_start(label, False)
+    if type(widget) != type([]):
+        widget = [widget]
+    for w in widget:
+        hbox.pack_start(w,False)
+    label.set_use_underline(True)
+    label.set_mnemonic_widget(widget[0])
+    return hbox
