@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -137,17 +137,17 @@ class Gui(abstract.IntervalGui):
         # practice_box #
         ################
         self.g_repeat_melodic = gu.bButton(self.action_area,
-            _("Repeat _melodic"), lambda _o, self=self: self.m_t.play_melodic())
+            _("Repeat _melodic"), self.repeat_melodic)
 
-        self.g_repeat_melodic.set_sensitive(gtk.FALSE)
+        self.g_repeat_melodic.set_sensitive(False)
 
         self.g_give_up = gu.bButton(self.action_area, _("_Give up"), self.give_up)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+        self.g_give_up.set_sensitive(False)
         ##############
         # config_box #        
         ##############
         frame = gtk.Frame(_("Ask for these intervals"))
-        self.config_box.pack_start(frame, gtk.FALSE)
+        self.config_box.pack_start(frame, False)
 
         self.g_interval_selector = widgets.IntervalCheckBox(
                                           self.m_exname, 'intervals')
@@ -155,18 +155,18 @@ class Gui(abstract.IntervalGui):
         self.g_interval_selector.set_border_width(gnome.ui.PAD)
         frame.add(self.g_interval_selector)
         #------we need some space
-        self.config_box.pack_start(gtk.HBox(), gtk.FALSE,
+        self.config_box.pack_start(gtk.HBox(), False,
                                    padding=gnome.ui.PAD_SMALL)
         # -------------------------------------------------
-        hbox = gu.bHBox(self.config_box, gtk.FALSE)
+        hbox = gu.bHBox(self.config_box, False)
         hbox.set_spacing(gnome.ui.PAD)
         hbox.pack_start(gtk.Label(_("Try to keep question with range from")),
-                        gtk.FALSE)
+                        False)
         lowspin = widgets.NotenameSpinButton(self.get_string('lowest_tone'))
-        hbox.pack_start(lowspin, gtk.FALSE)
-        gu.bLabel(hbox, _("to"), gtk.FALSE)
+        hbox.pack_start(lowspin, False)
+        gu.bLabel(hbox, _("to"), False)
         highspin = widgets.NotenameSpinButton(self.get_string('highest_tone'))
-        hbox.pack_start(highspin, gtk.FALSE)
+        hbox.pack_start(highspin, False)
         self.m_notenamerange = widgets.nNotenameRangeController(lowspin, highspin,
                            mpd.LOWEST_NOTENAME, mpd.HIGHEST_NOTENAME,
                            self.m_t.m_exname, 'lowest_tone', 'highest_tone')
@@ -174,9 +174,9 @@ class Gui(abstract.IntervalGui):
         # ------------------------------------------
         self._add_auto_new_question_gui(self.config_box)
         # ----------------------------------------------
-        hbox = gu.bHBox(self.config_box, gtk.FALSE)
+        hbox = gu.bHBox(self.config_box, False)
         hbox.set_spacing(gnome.ui.PAD_SMALL)
-        gu.bLabel(hbox, _("Input interface:"), gtk.FALSE)
+        gu.bLabel(hbox, _("Input interface:"), False)
 
         optionmenu = gtk.OptionMenu()
         menu = gtk.Menu()
@@ -187,7 +187,7 @@ class Gui(abstract.IntervalGui):
                          lambda widget, i=i: self.use_inputwidget(i))
         optionmenu.set_menu(menu)
         optionmenu.set_history(self.get_int('inputwidget'))
-        hbox.pack_start(optionmenu, gtk.FALSE)
+        hbox.pack_start(optionmenu, False)
 
         self.g_disable_unused_buttons = gu.nCheckButton(self.m_exname,
                     'disable_unused_intervals', _("_Disable unused buttons"))
@@ -195,7 +195,7 @@ class Gui(abstract.IntervalGui):
         # ------------ frame -------------------
         self.g_instrument_configurator = widgets.InstrumentConfigurator(
                                                              self.m_exname, 2)
-        self.config_box.pack_start(self.g_instrument_configurator, gtk.FALSE)
+        self.config_box.pack_start(self.g_instrument_configurator, False)
         self.config_box.set_spacing(0)
         self.config_box.show_all()
         ##############
@@ -209,9 +209,9 @@ class Gui(abstract.IntervalGui):
             self.g_flashbar.push(_("The answer is: %s")
                  % const.int_interval[self.m_t.m_interval])
             self.m_t.give_up()
-            self.g_new_interval.set_sensitive(gtk.TRUE)
+            self.g_new_interval.set_sensitive(True)
             self.g_new_interval.grab_focus()
-            self.g_give_up.set_sensitive(gtk.FALSE)
+            self.g_give_up.set_sensitive(False)
     def get_interval_input_list(self):
         return self.get_list('intervals')
     def click_on_interval(self, mouse_button, interval, midi_int):
@@ -235,12 +235,12 @@ class Gui(abstract.IntervalGui):
             elif self.m_t.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG):
                 if self.m_t.guess_answer(interval):
                     self.g_flashbar.flash(_("Correct"))
-                    self.g_new_interval.set_sensitive(gtk.TRUE)
+                    self.g_new_interval.set_sensitive(True)
                     self.g_new_interval.grab_focus()
-                    self.g_give_up.set_sensitive(gtk.FALSE)
+                    self.g_give_up.set_sensitive(False)
                 else:
                     self.g_flashbar.flash(_("Wrong"))
-                    self.g_give_up.set_sensitive(gtk.TRUE)
+                    self.g_give_up.set_sensitive(True)
                     if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
                         self.m_t.play_question()
             self.g_input.set_first_note(self.m_t.m_tonika)
@@ -269,8 +269,8 @@ class Gui(abstract.IntervalGui):
         """
         g = self.m_t.new_question()
         if g == Teacher.OK: # new question, everything is OK
-            self.g_repeat.set_sensitive(gtk.TRUE)
-            self.g_repeat_melodic.set_sensitive(gtk.TRUE)
+            self.g_repeat.set_sensitive(True)
+            self.g_repeat_melodic.set_sensitive(True)
             self.g_input.set_first_note(self.m_t.m_tonika)
             self.g_new_interval.set_sensitive(
               not self.get_bool('config/picky_on_new_question'))
@@ -282,11 +282,14 @@ class Gui(abstract.IntervalGui):
         elif g == Teacher.ERR_PICKY:
                 self.g_flashbar.flash(_("You have to solve this question first."))
         elif g == Teacher.ERR_NO_INTERVALLS:
-            self.g_repeat.set_sensitive(gtk.FALSE)
-            self.g_repeat_melodic.set_sensitive(gtk.FALSE)
+            self.g_repeat.set_sensitive(False)
+            self.g_repeat_melodic.set_sensitive(False)
             self.g_flashbar.clear()
             self.g_flashbar.flash(
                     _("You have to select some intervals to practise."))
+    def repeat_melodic(self, *w):
+        self.m_t.play_melodic()
+        self.g_input.grab_focus_first_sensitive_button()
     def on_start_practise(self):
         self.m_t.m_statistics.reset_session()
         self.g_new_interval.grab_focus()
@@ -294,9 +297,9 @@ class Gui(abstract.IntervalGui):
             self.g_flashbar.flash(_("Click 'New interval' to begin.")))
     def on_end_practise(self):
         self.m_t.end_practise()
-        self.g_new_interval.set_sensitive(gtk.TRUE)
-        self.g_repeat.set_sensitive(gtk.FALSE)
-        self.g_repeat_melodic.set_sensitive(gtk.FALSE)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+        self.g_new_interval.set_sensitive(True)
+        self.g_repeat.set_sensitive(False)
+        self.g_repeat_melodic.set_sensitive(False)
+        self.g_give_up.set_sensitive(False)
         self.g_flashbar.clear()
         self.g_input.clear()
