@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
 import gettext
 import locale
 import os
-import sys
 import configureoutput
 
 def _i(s):
@@ -55,7 +54,12 @@ def langs():
             retval.append(s)
     return retval
 
-gettext.install('solfege', os.path.join(configureoutput.prefix, 'share/locale'), unicode=1)
-__builtins__['_i'] = _i
+def setup():
+    gettext.install('solfege', os.path.join(configureoutput.prefix, 'share/locale'), unicode=1)
+    __builtins__['_i'] = _i
+
+def setup_srcdir():
+    gettext.install('solfege', 'share/locale', unicode=1)
+    __builtins__['_i'] = _i
 
 
