@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,10 +15,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import gnome, gtk, GDK
+import gnome, gtk
 import soundcard
 import abstract, const, statistics, statisticsviewer, gu, random
-from i18n import _
 
 
 class Teacher(abstract.Teacher):
@@ -52,7 +51,7 @@ class Teacher(abstract.Teacher):
         for x in self.m_practise_these.keys():
             if self.m_practise_these[x]:
                 v.append(x)
-        return v
+        return v#UGH
         return self.m_practise_these
         v = []
         for i in range(self.get_int('level')):
@@ -93,7 +92,12 @@ class Teacher(abstract.Teacher):
                 self.m_statistics.add_wrong(str(self.m_question), str(bpm))
             self.q_status = const.QSTATUS_WRONG
             self.m_app.play_sad_sound()
-
+    def end_practise(self):
+        self.stop_question()
+    def give_up(self):
+        self.stop_question()
+        print "FIXME not saving statistics"
+        self.q_status = const.QSTATUS_GIVE_UP
 
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
@@ -101,15 +105,15 @@ class Gui(abstract.Gui):
         ################
         # practise_box #
         ################
-        self.practise_box.set_spacing(gnome.uiconsts.PAD)
+        self.practise_box.set_spacing(gnome.ui.PAD)
         self.m_buttons = []
-        vbox = gu.bVBox(self.practise_box, gtk.FALSE)
+        vbox = gu.bVBox(self.practise_box, False)
         for s, e in ((0, 9), (9, 18), (18, 26), (26, 34)):
-            box = gtk.GtkHBox()
+            box = gtk.HBox()
             vbox.pack_start(box)
             for i in range(s, e):
                 bpm = self.m_t.m_bpms[i]
-                button = gtk.GtkButton(str(bpm))
+                button = gtk.Button(str(bpm))
                 box.pack_start(button)
                 button.connect('clicked', self.on_click)
                 button.connect('event', self.on_event)
@@ -118,20 +122,19 @@ class Gui(abstract.Gui):
 
         self.g_flashbar = gu.FlashBar()
         self.g_flashbar.show()
-        self.practise_box.pack_start(self.g_flashbar, gtk.FALSE)
+        self.practise_box.pack_start(self.g_flashbar, False)
 
-        gu.bButton(self.action_area, _("New tempo"), self.on_new)
-        gu.bButton(self.action_area, _("Stop"),
-                  lambda f, self=self: self.m_t.stop_question())
-        gu.bButton(self.action_area, _("Show answer"), self.on_show_answer)
+        self.g_new = gu.bButton(self.action_area, _("_New tempo"), self.on_new)
+        self.g_give_up = gu.bButton(self.action_area, _("_Give up"), self.on_give_up)
+        self.g_give_up.set_sensitive(False)
         self.practise_box.show_all()
         ##############
         # statistics #
         ##############
         self.g_statview = statisticsviewer.StatisticsViewer(self.m_t.m_statistics, 'Bpm')
         self.g_statview.show()
-        self.g_notebook.append_page(self.g_statview, 
-                                    gtk.GtkLabel(_("Statistics")))
+        self.g_notebook.append_page(self.g_statview,
+                                    gtk.Label(_("Statistics")))
         ########
         # init #
         ########
@@ -140,7 +143,7 @@ class Gui(abstract.Gui):
     def on_enable_bpm(self, _o=None):
         print "enable", _o
     def on_event(self, button, event):
-        if event.type == GDK.BUTTON_RELEASE and event.button == 3:
+        if event.type == gtk.gdk.BUTTON_RELEASE and event.button == 3:
             self.m_t.toggle_active(button.get_data('bpm'))
             self.update_buttons()
     def on_level_change(self, adjustment):
@@ -148,16 +151,25 @@ class Gui(abstract.Gui):
         self.update_buttons()
     def on_new(self, _o=None):
         self.m_t.new_question()
-    def on_show_answer(self, _o):
+        self.g_new.set_sensitive(
+          not self.get_bool('config/picky_on_new_question'))
+        self.g_give_up.set_sensitive(True)
+        self.m_buttons[0].grab_focus()
+    def on_give_up(self, _o):
+        self.m_t.give_up()
         self.g_flashbar.flash(str(self.m_t.m_question))
+        self.g_new.set_sensitive(True)
+        self.g_give_up.set_sensitive(False)
     def update_buttons(self):
         v = self.m_t.get_possible_bpms()
         for b in self.m_buttons:
             if b.get_data('bpm') in v:
-                b.children()[0].set_name("BpmActiveLabel")
+                b.get_children()[0].set_name("BpmActiveLabel")
             else:
-                b.children()[0].set_name("BpmInactiveLabel")
+                b.get_children()[0].set_name("BpmInactiveLabel")
     def on_click(self, _o):
+        if self.m_t.q_status in (const.QSTATUS_SOLVED, const.QSTATUS_GIVE_UP):
+            return
         if _o.get_data('bpm') not in self.m_t.get_possible_bpms():
             return
         if self.m_t.q_status == const.QSTATUS_NO:
@@ -165,6 +177,15 @@ class Gui(abstract.Gui):
             return
         if self.m_t.guess_answer(_o.get_data('bpm')):
             self.g_flashbar.flash(_("Correct, it is %i") % _o.get_data('bpm'))
+            self.g_give_up.set_sensitive(False)
+            self.g_new.set_sensitive(True)
+            self.g_new.grab_focus()
         else:
             self.g_flashbar.flash(_("Wrong"))
         self.g_statview.update()
+    def on_start_practise(self):
+        self.g_new.grab_focus()
+    def on_end_practise(self):
+        self.m_t.end_practise()
+        self.g_new.set_sensitive(True)
+        self.g_give_up.set_sensitive(False)
