@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -119,16 +119,16 @@ right now. But I can answer questions if needed.""")))
 
         self.g_flashbar = gu.FlashBar()
         self.g_flashbar.show()
-        self.practise_box.pack_start(self.g_flashbar, gtk.FALSE)
+        self.practise_box.pack_start(self.g_flashbar, False)
         self.practise_box.set_spacing(gnome.ui.PAD)
 
         self.g_new_tone = gu.bButton(self.action_area, _("_New tone"),
                                      self.new_question)
         self.g_repeat = gu.bButton(self.action_area, _("_Repeat"),
                   lambda _o, self=self: self.m_t.play_question())
-        self.g_repeat.set_sensitive(gtk.FALSE)
+        self.g_repeat.set_sensitive(False)
         self.g_give_up = gu.bButton(self.action_area, _("_Give up"), self.give_up)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+        self.g_give_up.set_sensitive(False)
         self.practise_box.show_all()
         ##############
         # config_box #
@@ -137,7 +137,7 @@ right now. But I can answer questions if needed.""")))
         table = gtk.Table()
         table.set_border_width(gnome.ui.PAD_SMALL)
         frame = gtk.Frame(_("Weight"))
-        self.config_box.pack_start(frame, gtk.FALSE)
+        self.config_box.pack_start(frame, False)
         frame.add(table)
         for x, n in [(1, 'cis'), (3, 'dis'), (7, 'fis'),
                      (9, 'gis'), (11, 'ais')]:
@@ -158,12 +158,12 @@ right now. But I can answer questions if needed.""")))
                    gtk.Adjustment(1, 0, 1000, 1, 10), digits=0)
              table.attach(b, x, x+2, 3, 4, xoptions=gtk.FILL)
 
-        hbox = gu.bHBox(self.config_box, gtk.FALSE)
-        hbox.pack_start(gtk.Label(_("Octave:")), gtk.FALSE, padding=4)
+        hbox = gu.bHBox(self.config_box, False)
+        hbox.pack_start(gtk.Label(_("Octave:")), False, padding=4)
         for oct in self.m_t.OCTAVES:
             b = gu.nCheckButton(self.m_exname, "octave"+str(oct), str(oct),
                                 default_value=1)
-            hbox.pack_start(b, gtk.FALSE)
+            hbox.pack_start(b, False)
         #############
         self._add_auto_new_question_gui(self.config_box)
         #############
@@ -175,7 +175,7 @@ right now. But I can answer questions if needed.""")))
                     "warning_sound", _("Play warning sound")))
         vbox.pack_start(gu.nCheckButton(self.m_exname, "one_chance_only",
                   _("Only one chance to get the answer right")))
-        self.config_box.pack_start(frame, gtk.FALSE)
+        self.config_box.pack_start(frame, False)
         self.config_box.show_all()
         ##############
         # statistics #
@@ -192,7 +192,7 @@ _("""You have to select some tones practise. Do this on the config page by setti
         elif g == Teacher.OK:
             self.g_new_tone.set_sensitive(
                   not self.get_bool('config/picky_on_new_question'))
-            self.g_repeat.set_sensitive(gtk.TRUE)
+            self.g_repeat.set_sensitive(True)
             if s in (const.QSTATUS_NO, const.QSTATUS_GIVE_UP):
                 self.g_flashbar.flash(_("First tone is %s")
                                       % self.m_t.m_question)
@@ -211,8 +211,8 @@ _("""You have to select some tones practise. Do this on the config page by setti
         elif self.m_t.q_status in (const.QSTATUS_NEW, const.QSTATUS_WRONG):
             if self.m_t.guess_answer(notename):
                 self.g_flashbar.flash(_("Correct"))
-                self.g_new_tone.set_sensitive(gtk.TRUE)
-                self.g_give_up.set_sensitive(gtk.FALSE)
+                self.g_new_tone.set_sensitive(True)
+                self.g_give_up.set_sensitive(False)
             else:
                 self.g_flashbar.flash(_("Wrong"))
                 if self.get_bool('one_chance_only'):
@@ -222,7 +222,7 @@ _("""You have to select some tones practise. Do this on the config page by setti
                     else:
                         self.m_t.play_question()
                 else:
-                    self.g_give_up.set_sensitive(gtk.TRUE)
+                    self.g_give_up.set_sensitive(True)
                     if self.get_bool("warning_sound"):
                         if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
                             self.m_t.spank_me_play_question()
@@ -237,9 +237,9 @@ _("""You have to select some tones practise. Do this on the config page by setti
             self.g_flashbar.push(_("The answer is: %s")
                 % self.m_t.m_question)
             self.m_t.give_up()
-            self.g_new_tone.set_sensitive(gtk.TRUE)
+            self.g_new_tone.set_sensitive(True)
             self.g_new_tone.grab_focus()
-            self.g_give_up.set_sensitive(gtk.FALSE)
+            self.g_give_up.set_sensitive(False)
     def set_percentage_label(self):
         self.g_percentage.set_text("%.1f %%" % (self.m_t.m_statistics.get()*100))
     def on_start_practise(self):
@@ -249,12 +249,12 @@ _("""You have to select some tones practise. Do this on the config page by setti
         self.set_percentage_label()
         gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New tone' to begin.")))
-        self.g_new_tone.set_sensitive(gtk.TRUE)
+        self.g_new_tone.set_sensitive(True)
         self.g_new_tone.grab_focus()
-        self.g_repeat.set_sensitive(gtk.FALSE)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+        self.g_repeat.set_sensitive(False)
+        self.g_give_up.set_sensitive(False)
         self.m_t.q_status = const.QSTATUS_NO
     def on_end_practise(self):
         self.m_t.end_practise()
         if configureoutput.WITH_GNOME:
-            self.g_repeat.set_sensitive(gtk.FALSE)
+            self.g_repeat.set_sensitive(False)
