@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,12 +16,11 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import sys, os, time, random
-# Hack to make module testing work.
-__builtins__['app_running'] = 'solfege'
 
 # i18n should be imported very early in program init because it setup
 # the _ and _i functions for the whole program.
 import i18n
+i18n.setup()
 
 import configureoutput
 
@@ -46,13 +45,13 @@ This is free software. It is covered by the GNU General Public License,
 and you are welcome to change it and/or distribute copies of it under
 certain conditions. Invoke as `solfege --warranty` for more information.
 
-Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen <tca@gnu.org>
+Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen <tca@gnu.org>
             """ % configureoutput.VERSION_STRING
             sys.exit()
 
         if '-w' in argv or '--warranty' in argv:
             print """GNU Solfege %s
-Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen <tca@gnu.org>
+Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen <tca@gnu.org>
 
     This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License version 2
@@ -80,11 +79,12 @@ if '--gtk-help' in sys.argv:
 # silent, GNOME, be silent!
 sys.argv.append('--disable-sound')
 
-try:
-    import pygtk
+import pygtk
+# this is needed for py2exe
+if sys.platform == 'win32':
+    os.environ['PATH'] += ";lib;bin;"
+else:
     pygtk.require("2.0")
-except:
-    pass
 
 if not configureoutput.WITH_GNOME:
     sys.path.insert(0, "gnomeemu")
@@ -105,7 +105,7 @@ class SplashWin(gtk.Window):
     def __init__(self):
         gtk.Window.__init__(self, gtk.WINDOW_POPUP)
         self.set_position(gtk.WIN_POS_CENTER)
-        self.set_resizable(gtk.TRUE)
+        self.set_resizable(True)
         frame = gtk.Frame()
         frame.set_shadow_type(gtk.SHADOW_OUT)
         self.add(frame)
@@ -167,11 +167,12 @@ import app
 from htmlwidget import HtmlWidget
 import utils, history
 from configwindow import ConfigWindow
-import mpd, mpd.musicdisplayer, gu, cfg
 import soundcard
+import mpd, mpd.musicdisplayer, gu, cfg
+
 
 import chord, chordvoicing, harmonicinterval, melodicinterval, \
-       singinterval, identifyscale, idbyname, dictation, twelvetone, \
+       singinterval, idbyname, dictation, twelvetone, \
        idtone, compareintervals, singchord, rhythm, identifybpm, \
        harmonicprogressiondictation
 
@@ -187,7 +188,7 @@ class DocViewer(gtk.VBox):
         self.on_key_press_event = self.m_htmlwidget.on_key_press_event
         self.m_statusbar = gtk.Statusbar()
         self.m_statusbar.show()
-        self.pack_start(self.m_statusbar, gtk.FALSE)
+        self.pack_start(self.m_statusbar, False)
         self.source = self.m_htmlwidget.source
         self.grab_focus = self.m_htmlwidget.grab_focus
     def read_docfile(self, fn, anchor):
@@ -232,9 +233,8 @@ class MusicViewerWindow(gtk.Dialog):
 class MainWin(gnome.ui.App, cfg.ConfigUtils):
     def __init__(self, argv):
         gnome.ui.App.__init__(self, 'solfege19', 'GNU Solfege')
-        im = gtk.Image()
-        im.set_from_file(os.path.join("graphics", "solfege.png"))
-        self.set_icon(im.get_pixbuf())
+        self.set_icon(gtk.gdk.pixbuf_new_from_file(
+                os.path.join("graphics", "solfege.png")))
         cfg.ConfigUtils.__dict__['__init__'](self, 'mainwin')
         self.set_resizable(self.get_bool('gui/mainwin_user_resizeable'))
         self.connect('destroy', self.quit_program)
@@ -256,9 +256,19 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         self.setup_toolbar()
         self.setup_menubar()
         self.m_app.handle_href('welcome.html')
-    def display_error_message(self, msg):
+    def dialog_yesno(self, text):
+        """Return True if the answer is yes, False if the answer is no.
+        """
+        m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_QUESTION,
+                gtk.BUTTONS_YES_NO, text)
+        ret = m.run()
+        m.destroy()
+        return ret == gtk.RESPONSE_YES
+    def display_error_message(self, msg, title=None):
         m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR,
                               gtk.BUTTONS_CLOSE, msg)
+        if title:
+            m.set_title(title)
         m.run()
         m.destroy()
     def display_question_music_error_message(self, idx, lessonfile, exception):
@@ -267,15 +277,13 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
     def show_about_window(self, widget):
         #if not self.g_about_window:
         if 1:
-            im = gtk.Image()
-            im.set_from_file(os.path.join("graphics", "solfege.png"))
             trans = _("SOLFEGETRANSLATORS")
             if trans == 'SOLFEGETRANSLATORS':
                 trans = ""
             self.g_about_window = gnome.ui.About("GNU Solfege",
                   configureoutput.VERSION_STRING,
-                  "Copyright (C) 2000, 2001, 2002, 2003 Tom Cato Amundsen",
-                  _("GPL'ed eartraining.") + "\n" + "http://www.solfege.org",
+                  "Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen",
+                  _("GPL'ed ear training.") + "\n" + "http://www.solfege.org",
                   ["Tom Cato Amundsen",
                   'Oliver Vollmer %s' % _("(toolbar icons)"),
                   'Giovanni Chierico %s' % _("(some lessonfiles)"),
@@ -284,7 +292,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
                   ],
                   ["Tom Cato Amundsen"],
                   trans,
-                  im.get_pixbuf())
+                  gtk.gdk.pixbuf_new_from_file(os.path.join("graphics", "solfege.png")))
             #self.g_about_window.connect('destroy', self.hide_about_window)
             #self.g_about_window.show()
             #FIXME this sucks.
@@ -390,26 +398,76 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             menubar.add(menuitem)
             menuitem.set_submenu(func(ag))
         self.g_menubar.show_all()
+    def create_ex_menu(self, exlist, ag):
+        menu = gtk.Menu()
+        for ex in exlist:
+            if type(ex) == type(""):
+                if const.exercisedata[ex][1]:
+                    item = gtk.ImageMenuItem(const.exercisedata[ex][0])
+                    im = gtk.Image()
+                    im.set_from_file(os.path.join('graphics', const.exercisedata[ex][1]))
+                    im.set_from_pixbuf(im.get_pixbuf().scale_simple(16, 16, gtk.gdk.INTERP_TILES))
+                    item.set_image(im)
+                else:
+                    item = gtk.MenuItem(const.exercisedata[ex][0])
+                if const.exercisedata[ex][2]:
+                    item.add_accelerator('activate', ag, const.exercisedata[ex][2], const.exercisedata[ex][3], gtk.ACCEL_VISIBLE)
+                if len(const.exercisedata[ex]) >= 5:
+                    item.connect('activate', lambda o, self=self, ex=ex: self.m_app.handle_href(const.exercisedata[ex][4]))
+                else:
+                    item.connect('activate', lambda o, self=self, ex=ex: self.m_app.handle_href('solfege:practise/'+ex))
+                menu.add(item)
+            else:
+                item = gtk.ImageMenuItem(ex[0])
+                item.connect('activate', lambda o, url=ex[1]: self.m_app.handle_href(url))
+		if len(ex) > 2:
+                    im = gtk.Image()
+                    im.set_from_file(os.path.join('graphics', ex[2]))
+                    im.set_from_pixbuf(im.get_pixbuf().scale_simple(16, 16, gtk.gdk.INTERP_TILES))
+                    item.set_image(im)
+                menu.add(item)
+        return menu
     def create_file_menu(self, ag):
         menu = gtk.Menu()
         if self.get_bool("gui/menus_have_tearoff"):
             item = gtk.TearoffMenuItem()
             menu.add(item)
-        for ex in const.exercises:
-            box = gtk.HBox()
-            box.set_spacing(4)
-            if const.exercisedata[ex][1]:
-                item = gtk.ImageMenuItem(const.exercisedata[ex][0])
-                im = gtk.Image()
-                im.set_from_file(os.path.join('graphics', const.exercisedata[ex][1]))
-                im.set_from_pixbuf(im.get_pixbuf().scale_simple(16, 16, gtk.gdk.INTERP_TILES))
-                item.set_image(im)
-            else:
-                item = gtk.MenuItem(const.exercisedata[ex][0])
-            if const.exercisedata[ex][2]:
-                item.add_accelerator('activate', ag, const.exercisedata[ex][2], const.exercisedata[ex][3], gtk.ACCEL_VISIBLE)
-            item.connect('activate', lambda o, self=self, ex=ex: self.m_app.handle_href('solfege:practise/'+ex))
-            menu.add(item)
+        ##
+        menuitem = gtk.MenuItem(_("_Intervals"))
+        menu.add(menuitem)
+        menuitem.set_submenu(self.create_ex_menu(('harmonic-interval',
+                                                  'melodic-interval',
+                                                  'sing-interval',
+                                                  'compare-intervals'), ag))
+        ##
+        menuitem = gtk.MenuItem(_("_Chords"))
+        menu.add(menuitem)
+        menuitem.set_submenu(self.create_ex_menu(('chord',
+                                                  'chord-voicing',
+                                                  'sing-chord'), ag))
+        ##
+        menuitem = gtk.MenuItem(_("_Rhythm"))
+        menu.add(menuitem)
+        menuitem.set_submenu(self.create_ex_menu(('rhythm',
+                                                  'identify-bpm'), ag))
+        ##
+        menuitem = gtk.MenuItem(_("_Misc exercises"))
+        menu.add(menuitem)
+        menuitem.set_submenu(self.create_ex_menu((
+             (_("_Scales"), 'solfege:/id-by-name/solfege/scales', 'identifyscale24.png'),
+             (_("Scales in t_hirds"), 'solfege:/id-by-name/solfege/scales-thirds', 'identifyscale24.png'),
+                                                  'id-by-name',
+                                                  'dictation',
+                                                  'twelve-tone',
+                                                  'id-tone',
+                                                  'harmonic-progression-dictation'), ag))
+        ##
+        menuitem = gtk.MenuItem(_("_Theory"))
+        menu.add(menuitem)
+        menuitem.set_submenu(self.create_ex_menu(
+              ( ('_Scale names', 'theory-scales.html'),
+                ('_Intervals', 'theory-intervals.html'),
+               ), ag))
         item = gtk.MenuItem()
         item.add(gtk.HSeparator())
         menu.add(item)
@@ -498,7 +556,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         menu.add(item)
         for txt, url in (
                      (_("_Welcome"), 'welcome.html'),
-                     (_("_All help files"), 'index.html'),
+                     (_("_All help files"), 'toc.html'),
                      (_("All installed _lesson files"), 'solfege:all-lessonfiles'),
                      ('SEP', 'SEP'),
                      (_("_Copyright notice"), 'copyright.html'),
@@ -517,8 +575,6 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         item.connect('activate', self.show_about_window)
         menu.add(item)
         return menu
-    def experiment(self, w=None):
-        pass
     def quit_program(self, w=None):
         self.m_app.quit_program()
         gtk.main_quit()
@@ -549,8 +605,10 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             im.set_from_file(os.path.join('graphics', const.exercisedata[ex][1]))
             n = string.replace(const.exercisedata[ex][0], '_', '')
             button = self.g_toolbar.append_item(n, None, None, im, None, None)
-            button.connect('clicked',
-                  lambda button, ex=ex: self.m_app.handle_href("solfege:practice/"+ex))
+            if len(const.exercisedata[ex]) >= 5:
+                button.connect('clicked', lambda button, ex=ex: self.m_app.handle_href(const.exercisedata[ex][4]))
+            else:
+                button.connect('clicked', lambda button, ex=ex: self.m_app.handle_href("solfege:practice/"+ex))
         self.add_toolbar(self.g_toolbar, "toolbar", "normal", "top", 1, 0, 1)
         s = self.get_string('gui/toolbar_style')
         if not (s in ('icons', 'text', 'both')):
@@ -604,8 +662,8 @@ if splash_win:
 
 w = MainWin(args)
 w.show()
-w.post_constructor()
 if splash_win:
     splash_win.destroy()
+w.post_constructor()
 gtk.mainloop()
 
