@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -58,32 +58,32 @@ class Gui(abstract.IntervalGui):
     def __init__(self, teacher, window):
         abstract.IntervalGui.__init__(self, teacher, window)
         self.g_give_up = gu.bButton(self.action_area, _("_Give up"), self.give_up)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+        self.g_give_up.set_sensitive(False)
         ##############
         # config_box #
         ##############
         self.g_mici = widgets.MultipleIntervalConfigWidget(self.m_exname)
-        self.config_box.pack_start(self.g_mici, gtk.FALSE, gtk.FALSE)
-        self.config_box.pack_start(gtk.HBox(), gtk.FALSE,
+        self.config_box.pack_start(self.g_mici, False, False)
+        self.config_box.pack_start(gtk.HBox(), False,
                                    padding=gnome.ui.PAD_SMALL)
-        hbox = gu.bHBox(self.config_box, gtk.FALSE, gtk.FALSE)
+        hbox = gu.bHBox(self.config_box, False, False)
         hbox.set_spacing(gnome.ui.PAD)
         hbox.pack_start(gtk.Label(_("Try to keep question with range from")),
-                        gtk.FALSE)
+                        False)
         lowspin = widgets.NotenameSpinButton(self.get_string('lowest_tone'))
-        hbox.pack_start(lowspin, gtk.FALSE)
-        gu.bLabel(hbox, _("to"), gtk.FALSE)
+        hbox.pack_start(lowspin, False)
+        gu.bLabel(hbox, _("to"), False)
         highspin = widgets.NotenameSpinButton(self.get_string('highest_tone'))
-        hbox.pack_start(highspin, gtk.FALSE)
+        hbox.pack_start(highspin, False)
         self.m_notenamerange = widgets.nNotenameRangeController(lowspin, highspin,
                            mpd.LOWEST_NOTENAME, mpd.HIGHEST_NOTENAME,
                            self.m_t.m_exname, 'lowest_tone', 'highest_tone')
 
         self._add_auto_new_question_gui(self.config_box)
         # ----------------------------------
-        hbox = gu.bHBox(self.config_box, gtk.FALSE)
+        hbox = gu.bHBox(self.config_box, False)
         hbox.set_spacing(gnome.ui.PAD_SMALL)
-        gu.bLabel(hbox, _("Input interface:"), gtk.FALSE)
+        gu.bLabel(hbox, _("Input interface:"), False)
 
         optionmenu = gtk.OptionMenu()
         menu = gtk.Menu()
@@ -94,7 +94,7 @@ class Gui(abstract.IntervalGui):
                          lambda widget, i=i: self.use_inputwidget(i))
         optionmenu.set_menu(menu)
         optionmenu.set_history(self.get_int('inputwidget'))
-        hbox.pack_start(optionmenu, gtk.FALSE)
+        hbox.pack_start(optionmenu, False)
 
         self.g_disable_unused_buttons = gu.nCheckButton(self.m_exname,
                     'disable_unused_intervals', _("_Disable unused buttons"))
@@ -115,9 +115,9 @@ class Gui(abstract.IntervalGui):
                        len(self.m_t.m_question) > 1, 1)
             self.g_flashbar.push(_("The answer is: %s") % s)
             self.m_t.give_up()
-            self.g_new_interval.set_sensitive(gtk.TRUE)
+            self.g_new_interval.set_sensitive(True)
             self.g_new_interval.grab_focus()
-            self.g_give_up.set_sensitive(gtk.FALSE)
+            self.g_give_up.set_sensitive(False)
     def get_interval_input_list(self):
         v = []
         for x in range(self.get_int('number_of_intervals')):
@@ -159,14 +159,14 @@ class Gui(abstract.IntervalGui):
             if self.m_t.guess_answer(self.m_answer,
                                      self.g_input.know_directions()):
                 self.g_flashbar.flash(_("Correct"))
-                self.g_new_interval.set_sensitive(gtk.TRUE)
+                self.g_new_interval.set_sensitive(True)
                 self.g_new_interval.grab_focus()
-                self.g_give_up.set_sensitive(gtk.FALSE)
+                self.g_give_up.set_sensitive(False)
             else:
                 self.g_flashbar.flash(_("Wrong"))
                 if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
                     self.m_t.play_question()
-                self.g_give_up.set_sensitive(gtk.TRUE)
+                self.g_give_up.set_sensitive(True)
             self.m_answer = []
             self.g_input.set_first_note(self.m_t.m_tonika)
             self.msg = ""
@@ -180,10 +180,10 @@ class Gui(abstract.IntervalGui):
         if ret == Teacher.ERR_CONFIGURE:
             self.g_flashbar.clear()
             self.g_flashbar.flash(_("The exercise has to be better configured."))
-            self.g_repeat.set_sensitive(gtk.FALSE)
+            self.g_repeat.set_sensitive(False)
         elif ret == Teacher.OK:
-            self.g_repeat.set_sensitive(gtk.TRUE)
-            self.g_give_up.set_sensitive(gtk.FALSE)
+            self.g_repeat.set_sensitive(True)
+            self.g_give_up.set_sensitive(False)
             self.g_input.set_first_note(self.m_t.m_tonika)
             self.m_t.play_question()
             self.g_new_interval.set_sensitive(
@@ -201,8 +201,8 @@ class Gui(abstract.IntervalGui):
             self.g_flashbar.flash(_("Click 'New interval' to begin.")))
     def on_end_practise(self):
         self.m_t.end_practise()
-        self.g_new_interval.set_sensitive(gtk.TRUE)
-        self.g_repeat.set_sensitive(gtk.FALSE)
-        self.g_give_up.set_sensitive(gtk.FALSE)
+        self.g_new_interval.set_sensitive(True)
+        self.g_repeat.set_sensitive(False)
+        self.g_give_up.set_sensitive(False)
         self.g_input.clear()
         self.g_flashbar.clear()
