@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@ import gu, widgets
 import soundcard, mpd
 import abstract, const
 import random, string
-from i18n import _
 
 class Teacher(abstract.Teacher):
     def __init__(self, exname, app):
@@ -68,14 +67,14 @@ class Gui(abstract.Gui):
         # practice_box #
         ################
         hbox = gu.bHBox(self.practise_box)
-        adj = gtk.GtkAdjustment(2, 1, 20, 1, 10)
-        self.g_x = gtk.GtkSpinButton(adj, digits=0)
+        adj = gtk.Adjustment(2, 1, 20, 1, 10)
+        self.g_x = gtk.SpinButton(adj, digits=0)
         hbox.pack_start(self.g_x)
-        adj = gtk.GtkAdjustment(3, 1, 20, 1, 10)
-        self.g_y = gtk.GtkSpinButton(adj, digits=0)
+        adj = gtk.Adjustment(3, 1, 20, 1, 10)
+        self.g_y = gtk.SpinButton(adj, digits=0)
         hbox.pack_start(self.g_y)
-        adj = gtk.GtkAdjustment(130, 40, 400, 1, 10)
-        self.g_tempo = gtk.GtkSpinButton(adj, digits=0)
+        adj = gtk.Adjustment(130, 40, 400, 1, 10)
+        self.g_tempo = gtk.SpinButton(adj, digits=0)
         hbox.pack_start(self.g_tempo)
         gu.bButton(self.practise_box, _("Go"), self.go)
         gu.bButton(self.practise_box, _("Stop"), self.m_t.stop)
