@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -151,7 +151,7 @@ class RhythmViewer(gtk.Frame):
             gtk.timeout_remove(self.__timeout)
         self.clear()
         for x in range(self.m_num_beats):
-            self.g_box.pack_start(create_png_image('holder'), gtk.FALSE)
+            self.g_box.pack_start(create_png_image('holder'), False)
         self.m_data = []
     def clear_wrong_part(self):
         """When the user have answered the question, this method is used
@@ -168,19 +168,19 @@ class RhythmViewer(gtk.Frame):
             self.g_box.get_children()[n].destroy()
         self.m_data = self.m_data[:n]
         for x in range(n, self.m_num_beats):
-            self.g_box.pack_start(create_png_image('holder'), gtk.FALSE)
+            self.g_box.pack_start(create_png_image('holder'), False)
     def add_elem(self, fn):
         #UGH remove/rename/whatever?
         im = gtk.Image()
         im.set_from_file('graphics/%s' % fn)
         im.show()
-        self.g_box.pack_start(im, gtk.FALSE)
+        self.g_box.pack_start(im, False)
     def add_rhythm_element(self, i):
         assert len(self.m_data) <= self.m_num_beats
         if len(self.g_box.get_children()) >= self.m_num_beats:
             self.g_box.get_children()[self.m_num_beats-1].destroy()
         im = create_rhythm_image(RHYTHMS[i])
-        self.g_box.pack_start(im, gtk.FALSE)
+        self.g_box.pack_start(im, False)
         self.g_box.reorder_child(im, len(self.m_data))
         self.m_data.append(i)
     def backspace(self):
@@ -189,14 +189,14 @@ class RhythmViewer(gtk.Frame):
                 self.g_face.destroy()
                 self.g_face = None
             self.g_box.get_children()[len(self.m_data)-1].destroy()
-            self.g_box.pack_start(create_png_image('holder'), gtk.FALSE)
+            self.g_box.pack_start(create_png_image('holder'), False)
             del self.m_data[-1]
     def mark_wrong(self, idx):
         box = gtk.VBox()
         r = self.g_box.get_children()[idx]
         self.g_box.get_children()[idx].reparent(box)
-        box.pack_start(create_png_image('rhythm-wrong'), gtk.FALSE, gtk.FALSE)
-        self.g_box.pack_start(box, gtk.FALSE)
+        box.pack_start(create_png_image('rhythm-wrong'), False, False)
+        self.g_box.pack_start(box, False)
         self.g_box.reorder_child(box, idx)
         box.show_all()
     def len(self):
@@ -207,13 +207,13 @@ class RhythmViewer(gtk.Frame):
         self.g_face.connect('button_press_event', self.on_sadface_event)
         self.g_face.show()
         self.g_face.add(create_png_image('sadface-32x32'))
-        self.g_box.pack_start(self.g_face, gtk.FALSE)
+        self.g_box.pack_start(self.g_face, False)
     def happy_face(self):
         self.g_face = gtk.EventBox()
         self.g_face.connect('button_press_event', self.on_happyface_event)
         self.g_face.show()
         self.g_face.add(create_png_image("happyface-32x32"))
-        self.g_box.pack_start(self.g_face, gtk.FALSE)
+        self.g_box.pack_start(self.g_face, False)
     def on_happyface_event(self, obj, event):
         if event.type == gtk.gdk.BUTTON_PRESS and event.button == 1:
             self.g_parent.new_question()
@@ -226,7 +226,7 @@ class RhythmViewer(gtk.Frame):
         l.set_name("Feedback")
         l.set_alignment(0.0, 0.5)
         l.show()
-        self.g_box.pack_start(l, gtk.TRUE, gtk.TRUE)
+        self.g_box.pack_start(l, True, True)
         self.__timeout = gtk.timeout_add(const.NORMAL_WAIT, self.unflash)
     def unflash(self, *v):
         self.__timeout = None
@@ -237,60 +237,60 @@ class Gui(abstract.Gui):
     def __init__(self, teacher, window):
         abstract.Gui.__init__(self, teacher, window)
         self.m_key_bindings = {'backspace_ak': self.on_backspace}
-        hbox = gu.bHBox(self.practise_box, gtk.FALSE)
+        hbox = gu.bHBox(self.practise_box, False)
         for i in range(0, 8):
             b = self.pngbutton(i)
             if i == 0:
                 self.g_first_rhythm_button = b
-            hbox.pack_start(b, gtk.FALSE)
-        hbox = gu.bHBox(self.practise_box, gtk.FALSE)
+            hbox.pack_start(b, False)
+        hbox = gu.bHBox(self.practise_box, False)
         for i in range(8, 16):
-            hbox.pack_start(self.pngbutton(i), gtk.FALSE)
-        hbox = gu.bHBox(self.practise_box, gtk.FALSE)
+            hbox.pack_start(self.pngbutton(i), False)
+        hbox = gu.bHBox(self.practise_box, False)
         for i in range(16, 22):
-            hbox.pack_start(self.pngbutton(i), gtk.FALSE)
+            hbox.pack_start(self.pngbutton(i), False)
         #-------
-        self.practise_box.pack_start(gtk.HBox(), gtk.FALSE,
+        self.practise_box.pack_start(gtk.HBox(), False,
                                      padding=gnome.ui.PAD_SMALL)
         self.g_rhythm_viewer = RhythmViewer(self)
         self.g_rhythm_viewer.set_size_request(-1, 52)
         self.g_rhythm_viewer.create_holders()
-        self.practise_box.pack_start(self.g_rhythm_viewer, gtk.FALSE)
+        self.practise_box.pack_start(self.g_rhythm_viewer, False)
 
         # action area
         self.g_new = gu.bButton(self.action_area, _("_New"), self.new_question)
         self.g_repeat = gu.bButton(self.action_area, _("_Repeat"), self.repeat_question)
-        self.g_repeat.set_sensitive(gtk.FALSE)
+        self.g_repeat.set_sensitive(False)
         self.g_show = gu.bButton(self.action_area, _("_Give up"), self.give_up)
-        self.g_show.set_sensitive(gtk.FALSE)
+        self.g_show.set_sensitive(False)
 
         self.g_backspace = gu.bButton(self.action_area, _("_Backspace"),
                      self.on_backspace)
-        self.g_backspace.set_sensitive(gtk.FALSE)
+        self.g_backspace.set_sensitive(False)
         self.practise_box.show_all()
         ##############
         # config_box #
         ##############
         frame = gtk.Frame(_("Rhythms to use in question"))
-        self.config_box.pack_start(frame, gtk.FALSE)
+        self.config_box.pack_start(frame, False)
         vbox = gtk.VBox()
         vbox.set_border_width(gnome.ui.PAD_SMALL)
         frame.add(vbox)
-        hbox = gu.bHBox(vbox, gtk.FALSE)
+        hbox = gu.bHBox(vbox, False)
         for i in range(0, 8):
-            hbox.pack_start(self.pngcheckbutton(i), gtk.FALSE)
-        hbox = gu.bHBox(vbox, gtk.FALSE)
+            hbox.pack_start(self.pngcheckbutton(i), False)
+        hbox = gu.bHBox(vbox, False)
         for i in range(8, 16):
-            hbox.pack_start(self.pngcheckbutton(i), gtk.FALSE)
-        hbox = gu.bHBox(vbox, gtk.FALSE)
+            hbox.pack_start(self.pngcheckbutton(i), False)
+        hbox = gu.bHBox(vbox, False)
         for i in range(16, 22):
-            hbox.pack_start(self.pngcheckbutton(i), gtk.FALSE)
+            hbox.pack_start(self.pngcheckbutton(i), False)
         #--------    
-        self.config_box.pack_start(gtk.HBox(), gtk.FALSE,
+        self.config_box.pack_start(gtk.HBox(), False,
                                    padding=gnome.ui.PAD_SMALL)
 
-        table = gtk.Table(2, 4, gtk.FALSE)
-        self.config_box.pack_start(table, gtk.FALSE)
+        table = gtk.Table(2, 4, False)
+        self.config_box.pack_start(table, False)
         ###
         label = gtk.Label(_("Number of beats in question:"))
         label.set_alignment(1.0, 0.5)
@@ -311,20 +311,20 @@ class Gui(abstract.Gui):
         menu = gu.PercussionNameOptionMenu(self.m_exname, "countin_perc", "Claves")
         table.attach(menu, 2, 3, 1, 2, xoptions=gtk.FILL)
         #-----
-        self.config_box.pack_start(gtk.HBox(), gtk.FALSE,
+        self.config_box.pack_start(gtk.HBox(), False,
                                    padding=gnome.ui.PAD_SMALL)
         #------
-        hbox = gu.bHBox(self.config_box, gtk.FALSE)
+        hbox = gu.bHBox(self.config_box, False)
         hbox.set_spacing(gnome.ui.PAD_SMALL)
         hbox.pack_start(gu.nCheckButton(self.m_exname,
                  "not_start_with_rest",
-                 _("Don't start the question with a rest")), gtk.FALSE)
+                 _("Don't start the question with a rest")), False)
         sep = gtk.VSeparator()
-        hbox.pack_start(sep, gtk.FALSE)
-        hbox.pack_start(gtk.Label(_("Beats per minute:")), gtk.FALSE)
+        hbox.pack_start(sep, False)
+        hbox.pack_start(gtk.Label(_("Beats per minute:")), False)
         spin = gu.nSpinButton(self.m_exname, 'bpm',
                  gtk.Adjustment(60, 20, 240, 1, 10))
-        hbox.pack_start(spin, gtk.FALSE)
+        hbox.pack_start(spin, False)
         self._add_auto_new_question_gui(self.config_box)
         self.config_box.show_all()
     def pngbutton(self, i):
@@ -344,7 +344,7 @@ class Gui(abstract.Gui):
            return
         self.g_rhythm_viewer.backspace()
         if not self.g_rhythm_viewer.m_data:
-            self.g_backspace.set_sensitive(gtk.FALSE)
+            self.g_backspace.set_sensitive(False)
     def guess_element(self, sender, i):
         if self.m_t.q_status == const.QSTATUS_NO:
             self.g_rhythm_viewer.flash(_("Click 'New' to begin."))
@@ -357,10 +357,10 @@ class Gui(abstract.Gui):
         if self.g_rhythm_viewer.len() == len(self.m_t.m_question):
             if self.m_t.guess_answer(self.g_rhythm_viewer.m_data):
                 self.g_rhythm_viewer.happy_face()
-                self.g_new.set_sensitive(gtk.TRUE)
+                self.g_new.set_sensitive(True)
                 self.g_new.grab_focus()
-                self.g_backspace.set_sensitive(gtk.FALSE)
-                self.g_show.set_sensitive(gtk.FALSE)
+                self.g_backspace.set_sensitive(False)
+                self.g_show.set_sensitive(False)
             else:
                 v = []
                 for idx in range(len(self.m_t.m_question)):
@@ -370,15 +370,15 @@ class Gui(abstract.Gui):
                         self.g_rhythm_viewer.mark_wrong(x)
                 self.g_rhythm_viewer.sad_face()
         else:
-            self.g_backspace.set_sensitive(gtk.TRUE)
+            self.g_backspace.set_sensitive(True)
     def new_question(self, widget=None):
         g = self.m_t.new_question()
         if g == Teacher.OK:
             self.g_first_rhythm_button.grab_focus()
             self.g_rhythm_viewer.set_num_beats(self.get_int('num_beats'))
             self.g_rhythm_viewer.create_holders()
-            self.g_show.set_sensitive(gtk.TRUE)
-            self.g_repeat.set_sensitive(gtk.TRUE)
+            self.g_show.set_sensitive(True)
+            self.g_repeat.set_sensitive(True)
             self.g_new.set_sensitive(
                not self.get_bool('config/picky_on_new_question'))
             self.m_t.play_question()
@@ -386,7 +386,7 @@ class Gui(abstract.Gui):
             self.g_rhythm_viewer.flash(_("You have to solve this question first."))
         else:
             assert g == Teacher.ERR_NO_ELEMS
-            self.g_repeat.set_sensitive(gtk.FALSE)
+            self.g_repeat.set_sensitive(False)
             self.g_rhythm_viewer.flash(_("You have to configure this exercise properly"))
     def repeat_question(self, *w):
         self.m_t.play_question()
@@ -396,9 +396,9 @@ class Gui(abstract.Gui):
         self.g_new.grab_focus()
     def on_end_practise(self):
         self.m_t.end_practise()
-        self.g_new.set_sensitive(gtk.TRUE)
-        self.g_repeat.set_sensitive(gtk.FALSE)
-        self.g_show.set_sensitive(gtk.FALSE)
+        self.g_new.set_sensitive(True)
+        self.g_repeat.set_sensitive(False)
+        self.g_show.set_sensitive(False)
         self.g_rhythm_viewer.create_holders()
     def give_up(self, widget=None):
         if self.m_t.q_status == const.QSTATUS_NO:
@@ -407,8 +407,8 @@ class Gui(abstract.Gui):
         for i in self.m_t.m_question:
             self.g_rhythm_viewer.add_rhythm_element(i)
         self.m_t.q_status = const.QSTATUS_SOLVED
-        self.g_new.set_sensitive(gtk.TRUE)
+        self.g_new.set_sensitive(True)
         self.g_new.grab_focus()
-        self.g_show.set_sensitive(gtk.FALSE)
-        self.g_backspace.set_sensitive(gtk.FALSE)
+        self.g_show.set_sensitive(False)
+        self.g_backspace.set_sensitive(False)
 
