@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ import dataparser
 
 class Teacher(abstract.LessonbasedTeacher):
     def __init__(self, exname, app):
-        abstract.LessonbasedTeacher.__init__(self, exname, app, const.USE_SING_CHORD)
+        abstract.LessonbasedTeacher.__init__(self, exname, app)
         self.lessonfileclass = lessonfile.SingChordLessonfile
         try: # the lessonfile might contain errors.
             self.parse_lessonfile()
@@ -42,28 +42,7 @@ class Teacher(abstract.LessonbasedTeacher):
     def play_answer_arpeggio(self):
         if self.q_status == const.QSTATUS_NO:
             return
-        m = soundcard.Track()
-        m.set_bpm(self.get_int('config/default_bpm'))
-        m.set_patch(0, self.get_int('config/preferred_instrument'))
-        vel = self.get_int('config/preferred_instrument_velocity')
-        for x in [0, 1]:
-            v = self.m_P.get_satb_vector()[x]
-            s = string.split(string.strip(v), " ")
-            for n in s:
-                if self.get_string('user/sex') == 'female':
-                    m.note(4, 0, mpd.notename_to_int(n), vel)
-                else:
-                    m.note(4, 0, mpd.notename_to_int(n)-12, vel)
-        for x in [2, 3]:
-            v = self.m_P.get_satb_vector()[x]
-            s = string.split(string.strip(v), " ")
-            for n in s:
-                if self.get_string('user/sex') == 'male':
-                    m.note(4, 0, mpd.notename_to_int(n), vel)
-                else:
-                    m.note(4, 0, mpd.notename_to_int(n)+12, vel)
-        soundcard.synth.play_track(m)
-
+        self.m_P.play_question_musicformat_satb_arpeggio()
 
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
@@ -102,26 +81,26 @@ class Gui(abstract.LessonbasedGui):
         else:
             fontsize = self.get_int('config/feta_font_size=20')
             self.g_music_displayer.display(self.m_t.m_P.get_music(), fontsize)
-            self.g_play_answer.set_sensitive(gtk.TRUE)
+            self.g_play_answer.set_sensitive(True)
             self.m_t.play_440hz()
     def on_start_practise(self):
         # if we have not m_P, then parsing of the lessonfile failed,
         # and then we have no questions.
         if not self.m_t.m_P:
-            self.g_new.set_sensitive(gtk.FALSE)
+            self.g_new.set_sensitive(False)
         else:
-            self.g_new.set_sensitive(gtk.TRUE)
+            self.g_new.set_sensitive(True)
         self.g_new.grab_focus()
     def on_end_practise(self):
         self.m_t.end_practise()
-        self.g_play_answer.set_sensitive(gtk.FALSE)
+        self.g_play_answer.set_sensitive(False)
         self.g_music_displayer.clear(2)
     def update_gui_after_lessonfile_change(self):
         self.g_music_displayer.clear(2)
         if self.m_t.m_P:
-            self.g_new.set_sensitive(gtk.TRUE)
+            self.g_new.set_sensitive(True)
         else:
-            self.g_new.set_sensitive(gtk.FALSE)
-        self.g_play_answer.set_sensitive(gtk.FALSE)
+            self.g_new.set_sensitive(False)
+        self.g_play_answer.set_sensitive(False)
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
 
