@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,9 +17,10 @@
 
 import sys
 if __name__ == '__main__':
-    import pygtk
-    pygtk.require('2.0')
+    sys.path.append("src")
     sys.path.append(".")
+    import i18n
+    i18n.setup_srcdir()
 
 import time, os, pickle
 import shutil
@@ -299,7 +300,11 @@ class LessonStatistics(AbstractStatistics):
         return hash(open(os.path.expanduser(os.path.join(
             self.m_t.get_string('lessoncollections/%s' % self.m_cur_collection),
             self.m_cur_file))).read())
-
+    def key_to_pretty_name(self, key):
+        for question in self.m_t.m_P.m_questions:
+            if question.get_cname() == key:
+                return question.get_name()
+        return key
 
 class IntervalStatistics(Statistics):
     def key_to_pretty_name(self, key):
