@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -67,17 +67,17 @@ class Gui(abstract.Gui):
 
         self.g_new = gu.bButton(self.action_area, _("_New"), self.new_question)
         self.g_play_first_note = gu.bButton(self.action_area, _("_Play first note"), lambda f, s=self: s.m_t.play_question())
-        self.g_play_first_note.set_sensitive(gtk.FALSE)
+        self.g_play_first_note.set_sensitive(False)
         self.g_play_last_note = gu.bButton(self.action_area, _("Play _last note"), lambda f, s=self: s.m_t.play_last_note())
-        self.g_play_last_note.set_sensitive(gtk.FALSE)
+        self.g_play_last_note.set_sensitive(False)
         self.g_play_all = gu.bButton(self.action_area, _("Play _all"), lambda f, s=self: s.m_t.play_all_notes())
-        self.g_play_all.set_sensitive(gtk.FALSE)
+        self.g_play_all.set_sensitive(False)
         self.practise_box.show_all()
     def new_question(self, widget=None):
         self.m_t.new_question()
-        self.g_play_first_note.set_sensitive(gtk.TRUE)
-        self.g_play_last_note.set_sensitive(gtk.TRUE)
-        self.g_play_all.set_sensitive(gtk.TRUE)
+        self.g_play_first_note.set_sensitive(True)
+        self.g_play_last_note.set_sensitive(True)
+        self.g_play_all.set_sensitive(True)
         self.m_t.play_question()
         s = r"\staff{"
         for n in self.m_t.m_question:
@@ -90,6 +90,6 @@ class Gui(abstract.Gui):
         self.g_music_displayer.clear()
     def on_end_practise(self):
         self.m_t.end_practise()
-        self.g_play_first_note.set_sensitive(gtk.FALSE)
-        self.g_play_last_note.set_sensitive(gtk.FALSE)
-        self.g_play_all.set_sensitive(gtk.FALSE)
+        self.g_play_first_note.set_sensitive(False)
+        self.g_play_last_note.set_sensitive(False)
+        self.g_play_all.set_sensitive(False)
