@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,11 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-if __name__ == '__main__':
+try:
+    app_running == True
+except:
     import sys
+    sys.path.append("src")
     sys.path.append(".")
-    import src.i18n
-    import pygtk; pygtk.require("2.0")
+    import i18n
+    i18n.setup_srcdir()
+
 
 import gtk
 import string, re, math
@@ -144,14 +148,7 @@ def parse_url(s):
            (/(?P<fn>[\w\-\.]+))? # exercise or html file name
            ((?P<anchor>\#\w+))? # anchor
            (/(?P<collection>\w+))? # collection
-           (/(?P<lessonfile>[\w-]+))? # lesson file
-           (\?(?P<config>.*))? """, re.VERBOSE|re.DOTALL)
-    r = re.compile("""((?P<protocol>\w+):)? # protocol
-           ((?P<action>\w[\w-]*))? #practise|config|statistics))? # 
-           (/(?P<fn>[\w\-\.]+))? # exercise or html file name
-           ((?P<anchor>\#\w+))? # anchor
-           (/(?P<collection>\w+))? # collection
-           (/(?P<lessonfile>[\w-]+))? # lesson file
+           (/(?P<lessonfile>[\.\w-]+))? # lesson file
            (\?(?P<config>.*))? """, re.VERBOSE|re.DOTALL)
     m = r.match(s)
     if not m.group('protocol'):
@@ -248,4 +245,4 @@ if __name__ == '__main__':
         print parse_url("main.html#123")
         print parse_url("main.html")
         print parse_url("exercise:/main.html#23")
-        print parse_url("solfege:/harmonic-interval?intervals=[1, 2, 3]")
+        print parse_url("solfege:practise/id-by-name/solfege/fifth-small-pure-0.99")
