@@ -1,5 +1,5 @@
-# GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@ from instrumentselector import InstrumentSelector, InstrumentConfigurator
 from notenamespinbutton import NotenameRangeController, \
                                nNotenameRangeController, \
                                NotenameSpinButton
-from specialwidgets import QuestionNameButtonTable, HarmonicProgressionLabel
+from specialwidgets import QuestionNameButtonTable, QuestionNameCheckButtonTable, HarmonicProgressionLabel
 from multipleintervalconfigwidget import MultipleIntervalConfigWidget, \
                                           IntervalCheckBox
 from selectlessonfilewidget import SelectLessonfileWidget
